@@ -1,6 +1,9 @@
 package Elastic::Model;
-$Elastic::Model::VERSION = '0.29_2'; # TRIAL
-use Moose 2.06 ();
+{
+  $Elastic::Model::VERSION = '0.01'; # TRIAL
+}
+
+use Moose();
 use Moose::Exporter();
 use Carp;
 use namespace::autoclean;
@@ -9,20 +12,12 @@ Moose::Exporter->setup_import_methods(
     class_metaroles => { class => ['Elastic::Model::Meta::Class::Model'] },
     with_meta       => [
         qw(has_namespace has_typemap override_classes
-            has_analyzer has_tokenizer has_filter has_char_filter
-            has_unique_index)
+            has_analyzer has_tokenizer has_filter has_char_filter)
     ],
-    also => 'Moose',
+    base_class_roles => ['Elastic::Model::Role::Model'],
+    also             => 'Moose',
 );
 
-#===================================
-sub init_meta {
-#===================================
-    shift;
-    my $meta = Moose->init_meta(@_);
-    Moose::Util::apply_all_roles( $meta, 'Elastic::Model::Role::Model' );
-}
-
 #===================================
 sub has_namespace {
 #===================================
@@ -41,13 +36,6 @@ sub has_namespace {
 sub has_typemap { shift->set_class( 'typemap', @_ ) }
 #===================================
 
-#===================================
-sub has_unique_index {
-#===================================
-    my ( $meta, $val ) = @_;
-    $meta->unique_index($val);
-}
-
 #===================================
 sub override_classes {
 #===================================
@@ -84,21 +72,20 @@ sub has_char_filter {
 
 1;
 
-# ABSTRACT: A NoSQL document store with full text search for Moose objects using Elasticsearch as a backend.
+# ABSTRACT: A NoSQL document store with full text search for Moose objects using ElasticSearch as a backend.
+
+
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
-Elastic::Model - A NoSQL document store with full text search for Moose objects using Elasticsearch as a backend.
+Elastic::Model - A NoSQL document store with full text search for Moose objects using ElasticSearch as a backend.
 
 =head1 VERSION
 
-version 0.29_2
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -116,7 +103,7 @@ version 0.29_2
     # Setup custom analyzers
 
     has_filter 'edge_ngrams' => (
-        type     => 'edge_ngram',
+        type     => 'edgeNGram',
         min_gram => 2,
         max_gram => 10
     );
@@ -131,11 +118,11 @@ version 0.29_2
 =head1 DESCRIPTION
 
 Elastic::Model is a framework to store your Moose objects, which uses
-Elasticsearch as a NoSQL document store and flexible search engine.
+ElasticSearch as a NoSQL document store and flexible search engine.
 
-It is designed to make it easy to start using Elasticsearch with minimal extra
+It is designed to make it easy to start using ElasticSearch with minimal extra
 code, but allows you full access to the rich feature set available in
-Elasticsearch as soon as you are ready to use it.
+ElasticSearch as soon as you are ready to use it.
 
 =head1 INTRODUCTION TO Elastic::Model
 
@@ -145,29 +132,10 @@ L<Elastic::Manual::Intro>.
 The rest of the documentation on this page explains how to use the
 L<Elastic::Model> module itself.
 
-=head1 IMPORTANT
-
-This version of Elastic::Model has been updated to work with
-L<Search::Elasticsearch::Compat>, a compatibility layer over the new official
-Elasticsearch Perl client: L<Search::Elasticsearch>.
-
-In the near future, I will be releasing a version of Elastic::Model that
-works with L<Elasticsearch> directly, without need for the compatibility
-layer.  In the meantime, you should be able to continue using Elastic::Model
-as normal by simply changing:
-
-    use ElasticSearch;
-    my $es = ElasticSearch->new(...);
-
-to:
-
-    use Search::Elasticsearch::Compat;
-    my $es = Search::Elasticsearch::Compat->new(...);
-
 =head1 USING ELASTIC::MODEL
 
 Your application needs a C<model> class to handle the relationship between
-your object classes and the Elasticsearch cluster.
+your object classes and the ElasticSearch cluster.
 
 Your model class is most easily defined as follows:
 
@@ -193,13 +161,13 @@ handled by which of your classes.  So the above declaration says:
 
 I<"For all L<indices|Elastic::Model::Terminology/Index> which belong to namespace
 C<myapp>, objects of class C<MyApp::User> will be stored under the
-L<type|Elastic::Model::Terminology/Type> C<user> in Elasticsearch.">
+L<type|Elastic::Model::Terminology/Type> C<user> in ElasticSearch.">
 
 =head2 Custom TypeMap
 
 Elastic::Model uses a L<TypeMap|Elastic::Model::TypeMap::Default> to figure
 out how to inflate and deflate your objects, and how to configure them
-in Elasticsearch.
+in ElasticSearch.
 
 You can specify your own TypeMap using:
 
@@ -208,21 +176,11 @@ You can specify your own TypeMap using:
 See L<Elastic::Model::TypeMap::Base> for instructions on how to define
 your own type-map classes.
 
-=head2 Custom unique key index
-
-If you have attributes whose values are
-L<unique|Elastic::Manual::Attributes::Unique>, then you can customize the index
-where these unique values are stored.
-
-    has_unique_index 'myapp_unique';
-
-The default value is C<unique_key>.
-
 =head2 Custom analyzers
 
 Analysis is the process of converting full text into C<terms> or C<tokens> and
 is one of the things that gives full text search its power.  When storing text
-in the Elasticsearch index, the text is first analyzed into terms/tokens.
+in the ElasticSearch index, the text is first analyzed into terms/tokens.
 Then, when searching, search keywords go through the same analysis process
 to produce the terms/tokens which are then searched for in the index.
 
@@ -282,7 +240,7 @@ multiple token filters.  For instance, each term could be broken down into
 "edge ngrams" (eg 'foo' => 'f','fo','foo') for partial matching.
 
     has_filter 'my_ngrams' => (
-        type        => 'edge_ngram',
+        type        => 'edgeNGram',
         min_gram    => 1,
         max_gram    => 10,
     );
@@ -348,20 +306,12 @@ C<results> C<-------------> L<Elastic::Model::Results>
 
 =item *
 
-C<cached_results> C<------> L<Elastic::Model::Results::Cached>
-
-=item *
-
 C<scrolled_results> C<----> L<Elastic::Model::Results::Scrolled>
 
 =item *
 
 C<result> C<--------------> L<Elastic::Model::Result>
 
-=item *
-
-C<bulk> C<----------------> L<Elastic::Model::Bulk>
-
 =back
 
 =head1 SEE ALSO
@@ -388,9 +338,10 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Clinton Gormley.
+This software is copyright (c) 2012 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
