@@ -1,5 +1,8 @@
 package Elastic::Model::Alias;
-$Elastic::Model::Alias::VERSION = '0.29_2'; # TRIAL
+{
+  $Elastic::Model::Alias::VERSION = '0.01'; # TRIAL
+}
+
 use Carp;
 use Moose;
 with 'Elastic::Model::Role::Index';
@@ -14,15 +17,15 @@ sub to {
     my $self = shift;
 
     my $name    = $self->name;
-    my $store   = $self->model->store;
-    my %indices = (
-        (   map { $_ => { remove => { index => $_, alias => $name } } }
-                keys %{ $store->get_aliases( index => $name ) }
+    my $es      = $self->es;
+    my %indices = ( (
+            map { $_ => { remove => { index => $_, alias => $name } } }
+                keys %{ $es->get_aliases( index => $name ) }
         ),
         $self->_add_aliases(@_)
     );
 
-    $store->put_aliases( actions => [ values %indices ] );
+    $es->aliases( actions => [ values %indices ] );
     $self->model->domain($name)->clear_default_routing;
     $self->model->clear_domain_namespace;
     return $self;
@@ -33,7 +36,7 @@ sub add {
 #===================================
     my $self    = shift;
     my %indices = $self->_add_aliases(@_);
-    $self->model->store->put_aliases( actions => [ values %indices ] );
+    $self->es->aliases( actions => [ values %indices ] );
     $self->model->domain( $self->name )->clear_default_routing;
     return $self;
 }
@@ -44,7 +47,7 @@ sub remove {
     my $self    = shift;
     my $name    = $self->name;
     my @actions = map { { remove => { index => $_, alias => $name } } } @_;
-    $self->model->store->put_aliases( actions => \@actions );
+    $self->es->aliases( actions => \@actions );
     $self->model->clear_domain_namespace;
     return $self;
 }
@@ -52,10 +55,9 @@ sub remove {
 #===================================
 sub aliased_to {
 #===================================
-    my $self = shift;
-    my $name = $self->name;
-
-    my $indices = $self->model->store->get_aliases( index => $name );
+    my $self    = shift;
+    my $name    = $self->name;
+    my $indices = $self->es->get_aliases( index => $name );
     croak "($name) is an index, not an alias"
         if $indices->{$name};
 
@@ -65,12 +67,11 @@ sub aliased_to {
 #===================================
 sub _add_aliases {
 #===================================
-    my $self  = shift;
-    my $name  = $self->name;
-    my $store = $self->model->store;
+    my $self = shift;
+    my $name = $self->name;
+    my $es   = $self->es;
     my %indices;
 
-    my $builder;
     while (@_) {
         my $index  = shift @_;
         my %params = (
@@ -79,29 +80,26 @@ sub _add_aliases {
             alias => $name
         );
         if ( my $filter = delete $params{filterb} ) {
-            $builder ||= $self->model->view->search_builder;
-            $params{filter} = $builder->filter($filter)->{filter};
+            $params{filter} = $es->builder->filter($filter)->{filter};
         }
         $indices{$index} = { add => \%params };
     }
     return %indices;
 }
 
-__PACKAGE__->meta->make_immutable;
-
 1;
 
+
+
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
-Elastic::Model::Alias - Administer aliases in Elasticsearch
+Elastic::Model::Alias - Administer aliases in ElasticSearch
 
 =head1 VERSION
 
-version 0.29_2
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -123,7 +121,7 @@ See also L<Elastic::Model::Role::Index/SYNOPSIS>.
 =head1 DESCRIPTION
 
 L<Elastic::Model::Alias> objects are used to create and administer
-L<index aliases|Elastic::Manual::Terminology/Alias> in an Elasticsearch cluster.
+L<index aliases|Elastic::Manual::Terminology/Alias> in an ElasticSearch cluster.
 
 See L<Elastic::Model::Role::Index> for more about usage.
 See L<Elastic::Manual::Scaling> for more about how aliases can be used in your
@@ -241,14 +239,15 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Clinton Gormley.
+This software is copyright (c) 2012 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
 __END__
 
-# ABSTRACT: Administer aliases in Elasticsearch
+# ABSTRACT: Administer aliases in ElasticSearch
 
