@@ -1,9 +1,12 @@
 package Elastic::Model::Domain;
-$Elastic::Model::Domain::VERSION = '0.29_2'; # TRIAL
+{
+  $Elastic::Model::Domain::VERSION = '0.01'; # TRIAL
+}
+
 use Carp;
 use Moose;
 use namespace::autoclean;
-use MooseX::Types::Moose qw(Maybe Str);
+use MooseX::Types::Moose qw(:all);
 
 #===================================
 has 'name' => (
@@ -39,7 +42,7 @@ sub _get_default_routing {
 #===================================
     my $self    = shift;
     my $name    = $self->name;
-    my $aliases = $self->model->store->get_aliases( index => $name );
+    my $aliases = $self->model->es->get_aliases( index => $name );
 
     croak "Domain ($name) doesn't exist either as an index or an alias"
         unless %$aliases;
@@ -95,7 +98,7 @@ sub get {
 }
 
 #===================================
-sub try_get { shift->get( @_, ignore => 404 ) }
+sub try_get { shift->get( @_, ignore_missing => 1 ) }
 #===================================
 
 #===================================
@@ -133,7 +136,7 @@ sub delete {
 }
 
 #===================================
-sub try_delete { shift->delete( @_, ignore => 404 ) }
+sub try_delete { shift->delete( @_, ignore_missing => 1 ) }
 #===================================
 
 #===================================
@@ -145,9 +148,9 @@ sub view {
 
 1;
 
-=pod
 
-=encoding UTF-8
+
+=pod
 
 =head1 NAME
 
@@ -155,7 +158,7 @@ Elastic::Model::Domain - The domain (index or alias) where your docs are stored.
 
 =head1 VERSION
 
-version 0.29_2
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -313,13 +316,14 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Clinton Gormley.
+This software is copyright (c) 2012 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
 __END__
 
 # ABSTRACT: The domain (index or alias) where your docs are stored.
