@@ -1,5 +1,8 @@
 package Elastic::Model::Index;
-$Elastic::Model::Index::VERSION = '0.29_2'; # TRIAL
+{
+  $Elastic::Model::Index::VERSION = '0.01'; # TRIAL
+}
+
 use Carp;
 use Moose;
 with 'Elastic::Model::Role::Index';
@@ -13,7 +16,8 @@ sub create {
 #===================================
     my $self   = shift;
     my $params = $self->index_config(@_);
-    $self->model->store->create_index(%$params);
+
+    $self->es->create_index($params);
     return $self;
 }
 
@@ -31,7 +35,6 @@ sub reindex {
     my $bulk_size  = $args{bulk_size} || $size;
     my $dest_index = $self->name;
     my $model      = $self->model;
-    my $transform  = $args{transform} || sub {@_};
 
     printf "Reindexing domain ($domain) to index ($dest_index)\n" if $verbose;
 
@@ -45,10 +48,10 @@ sub reindex {
 
     # store all changed UIDs so that we can repoint them
     # later, when they're used in docs that aren't being reindexed
-    my %uids;
+    my @uids;
     my $doc_updater = sub {
-        my ($doc) = $transform->(@_);
-        $uids{ $doc->{_index} }{ $doc->{_type} }{ $doc->{_id} } = 1;
+        my ($doc) = @_;
+        push @uids, [ @{$doc}{qw(_index _type _id)} ];
         $doc->{_index} = $dest_index;
         return $doc;
     };
@@ -69,9 +72,9 @@ sub reindex {
     my $updater = $self->doc_updater( $doc_updater, $uid_updater );
 
     my $source = $model->view->domain($domain)->size($size)->scan($scan);
-    $model->store->reindex(
-        source      => sub { $source->shift_element },
-        verbose     => $verbose,
+    $model->es->reindex(
+        source      => $source->as_elements,
+        quiet       => !$verbose,
         transform   => $updater,
         bulk_size   => $bulk_size,
         on_conflict => $args{on_conflict},
@@ -81,8 +84,8 @@ sub reindex {
     return 1 unless $args{repoint_uids};
 
     $self->repoint_uids(
-        uids        => \%uids,
-        verbose     => $verbose,
+        uids        => \@uids,
+        quiet       => !$verbose,
         exclude     => [ keys %map ],
         size        => $size,
         bulk_size   => $bulk_size,
@@ -97,15 +100,15 @@ sub repoint_uids {
 #===================================
     my ( $self, %args ) = @_;
 
-    my $verbose    = $args{verbose};
+    my $verbose    = !$args{quiet};
     my $scan       = $args{scan} || '2m';
     my $size       = $args{size} || 1000;
     my $bulk_size  = $args{bulk_size} || $size;
     my $model      = $self->model;
     my $index_name = $self->name;
-    my $uids       = $args{uids} || {};
+    my $uids       = $args{uids} || [];
 
-    unless (%$uids) {
+    unless (@$uids) {
         print "No UIDs to repoint\n" if $verbose;
         return 1;
     }
@@ -118,12 +121,6 @@ sub repoint_uids {
         return 1;
     }
 
-    my @uid_attrs = $self->_uid_attrs_for_indices(@indices);
-    unless (@uid_attrs) {
-        print "No UIDs to repoint\n" if $verbose;
-        return 1;
-    }
-
     my $view = $model->view->domain( \@indices )->size($size);
 
     my $doc_updater = sub {
@@ -135,100 +132,48 @@ sub repoint_uids {
     my %map;
     my $uid_updater = sub {
         my $uid = shift;
-        return unless $uids->{ $uid->{index} }{ $uid->{type} }{ $uid->{id} };
-        $uid->{index} = $index_name;
+        my $key = join "\0", @{$uid}{ 'index', 'type', 'id' };
+        $uid->{index} = $index_name
+            if $map{$key};
     };
 
     my $updater = $self->doc_updater( $doc_updater, $uid_updater );
 
-    for my $index ( keys %$uids ) {
-        my $types = $uids->{$index};
-        for my $type ( keys %$types ) {
-            my @ids = keys %{ $types->{$type} };
+    printf( "Repointing %d UIDs\n", scalar @$uids ) if $verbose;
+    local $| = $verbose;
 
-            printf( "Repointing %d UIDs from %s/%s\n",
-                0 + @ids, $index, $type )
-                if $verbose;
+    while (@$uids) {
+        %map = ();
+        print "." if $verbose;
 
-            while (@ids) {
-
-                my $clauses
-                    = $self->_build_uid_clauses( \@uid_attrs, $index, $type,
-                    [ splice @ids, 0, $size ] );
-
-                my $source = $view->filter( or => $clauses )->scan($scan);
-                $model->store->reindex(
-                    source => sub {
-                        $source->shift_element;
-                    },
-                    bulk_size   => $bulk_size,
-                    quiet       => 1,
-                    transform   => $updater,
-                    on_conflict => $args{on_conflict},
-                    on_error    => $args{on_error},
-                );
-            }
-            print "\n" if $verbose;
+        my @clauses;
+        for ( splice @$uids, 0, $size ) {
+            $map{ join( "\0", @$_ ) } = 1;
+            push @clauses,
+                {
+                'uid.index' => $_->[0],
+                'uid.type'  => $_->[1],
+                'uid.id'    => $_->[2],
+                };
         }
+
+        my $source = $view->filterb( \@clauses )->scan($scan);
+
+        $model->es->reindex(
+            source      => $source->as_elements,
+            bulk_size   => $bulk_size,
+            quiet       => 1,
+            transform   => $updater,
+            on_conflict => $args{on_conflict},
+            on_error    => $args{on_error},
+        );
+
     }
 
     print "\nDone\n" if $verbose;
     return 1;
 }
 
-#===================================
-sub _uid_attrs_for_indices {
-#===================================
-    my $self    = shift;
-    my @indices = @_;
-    my $mapping = $self->model->store->get_mapping( index => \@indices );
-    my %attrs   = map { $_ => 1 }
-        map { _find_uid_attrs( $_->{properties} ) }
-        map { values %{ $_->{mappings} } } values %$mapping;
-    return keys %attrs;
-
-}
-
-#===================================
-sub _find_uid_attrs {
-#===================================
-    my ( $mapping, $level ) = @_;
-
-    my @attrs;
-    $level = '' unless $level;
-
-    keys %$mapping;
-    while ( my ( $k, $v ) = each %$mapping ) {
-        next unless $v->{properties};
-        my $attr = $level ? "$level.$k" : $k;
-
-        if ( $k eq 'uid' and $v->{properties} and $v->{properties}{index} ) {
-            push @attrs, $attr;
-            next;
-        }
-        push @attrs, _find_uid_attrs( $v->{properties} || {}, $attr );
-    }
-    return @attrs;
-}
-
-#===================================
-sub _build_uid_clauses {
-#===================================
-    my ( $self, $uid_attrs, $index, $type, $ids ) = @_;
-    my @clauses;
-    for my $id (@$ids) {
-        push @clauses, map {
-            +{  and => [
-                    { term => { "$_.index" => $index } },
-                    { term => { "$_.type"  => $type } },
-                    { term => { "$_.id"    => $id } }
-                ]
-                }
-        } @$uid_attrs;
-    }
-    return \@clauses;
-}
-
 #===================================
 sub doc_updater {
 #===================================
@@ -258,21 +203,19 @@ sub doc_updater {
     };
 }
 
-__PACKAGE__->meta->make_immutable;
-
 1;
 
+
+
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
-Elastic::Model::Index - Create and administer indices in Elasticsearch
+Elastic::Model::Index - Create and administer indices in ElasticSearch
 
 =head1 VERSION
 
-version 0.29_2
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -288,7 +231,7 @@ See also L<Elastic::Model::Role::Index/SYNOPSIS>.
 =head1 DESCRIPTION
 
 L<Elastic::Model::Index> objects are used to create and administer indices
-in an Elasticsearch cluster.
+in an ElasticSearch cluster.
 
 See L<Elastic::Model::Role::Index> for more about usage.
 See L<Elastic::Manual::Scaling> for more about how indices can be used in your
@@ -309,7 +252,7 @@ generated from the attributes of your doc classes listed in the
 L<namespace|Elastic::Model::Namespace>.  Similarly, any
 L<custom analyzers|Elastic::Model/"Custom analyzers"> required
 by your classes are added to the index
-L<\%settings|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-update-settings.html>
+L<\%settings|http://www.elasticsearch.org/guide/reference/api/admin-indices-update-settings.html>
 that you pass in:
 
     $index->create( settings => {number_of_shards => 1} );
@@ -334,8 +277,6 @@ L<namespace|Elastic::Model::Namespace>, pass in a list of C<@types>.
         scan            => '2m',
         quiet           => 0,
 
-        transform       => sub {...},
-
         on_conflict     => sub {...} | 'IGNORE'
         on_error        => sub {...} | 'IGNORE'
         uid_on_conflict => sub {...} | 'IGNORE'
@@ -374,7 +315,7 @@ are indexed into the new domain in a single bulk-indexing request.
 =item scan
 
 C<scan> is the same as L<Elastic::Model::View/scan> - it controls how long
-Elasticsearch should keep the "scroll" live between requests.  Defaults to
+ElasticSearch should keep the "scroll" live between requests.  Defaults to
 '2m'.  Increase this if the reindexing process is slow and you get
 scroll timeouts.
 
@@ -384,22 +325,6 @@ If true (the default), L</repoint_uids()> will be called automatically to
 update any L<UIDs|Elastic::Model::UID> (which point at the old index) in
 indices other than the ones currently being reindexed.
 
-=item transform
-
-If you need to change the structure/data of your doc while reindexing, you
-can pass a C<transform> coderef.  This will be called before any changes
-have been made to the doc, and should return the new doc. For instance,
-to convert the single-value C<tag> field to an array of C<tags>:
-
-    $index->reindex(
-        'new_index',
-        'transform' => sub {
-            my $doc = shift;
-            $doc->{_source}{tags} = [ delete $doc->{_source}{tag} ];
-            return $doc
-        }
-    );
-
 =item on_conflict / on_error
 
 If you are indexing to the new index at the same time as you are reindexing,
@@ -411,7 +336,7 @@ callback, or ignore them by by setting C<on_conflict> to C<'IGNORE'>:
 Similarly, you can pass an C<on_error> handler which will handle other errors,
 or all errors if no C<on_conflict> handler is defined.
 
-See L<Search::Elasticsearch::Compat/Error handlers> for more.
+See L<ElasticSearch/Error handlers> for more.
 
 =item uid_on_conflict / uid_on_error
 
@@ -451,8 +376,8 @@ Parameters:
 
 =item uids
 
-C<uids> is a hash ref the stale L<UIDs|Elastic::Model::UID> which should be
-updated.
+C<uids> is an array ref, containing a list of the stale
+L<UIDs|Elastic::Model::UID> which should be updated.
 
 For instance: you have reindexed C<myapp_v1> to C<myapp_v2>, but domain
 C<other> has documents with UIDs which point to C<myapp_v1>. You
@@ -460,14 +385,10 @@ can updated these by passing a list of the old UIDs, as follows:
 
     $index = $namespace->index('myapp_v2');
     $index->repoint_uids(
-        uids    => {                        # index
-            myapp_v1 => {                   # type
-                user => {
-                    1 => 1,                 # ids
-                    2 => 1,
-                }
-            }
-        }
+        uids    => [
+            ['myapp_v1','user',1], # ie old_index, type, ID
+            ['myapp_v1','user',2],
+        ]
     );
 
 =item exclude
@@ -584,14 +505,15 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Clinton Gormley.
+This software is copyright (c) 2012 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
 __END__
 
-# ABSTRACT: Create and administer indices in Elasticsearch
+# ABSTRACT: Create and administer indices in ElasticSearch
 
