@@ -1,8 +1,11 @@
 package Elastic::Model::Meta::Class::Model;
-$Elastic::Model::Meta::Class::Model::VERSION = '0.29_2'; # TRIAL
+{
+  $Elastic::Model::Meta::Class::Model::VERSION = '0.01'; # TRIAL
+}
+
 use Moose::Role;
 use List::Util ();
-use MooseX::Types::Moose qw(HashRef Str);
+use MooseX::Types::Moose qw(:all);
 use Carp;
 use Data::Dump qw(pp);
 use namespace::autoclean;
@@ -21,7 +24,7 @@ for my $k (qw(namespace char_filter analyzer filter tokenizer)) {
         is      => 'ro',
         traits  => ['Hash'],
         isa     => HashRef,
-        default => sub { +{%default} },
+        default => sub { \%default },
         handles => {
             $k          => 'get',
             "add_${k}"  => 'set',
@@ -59,10 +62,8 @@ has 'classes' => (
             view             => 'Elastic::Model::View',
             scope            => 'Elastic::Model::Scope',
             results          => 'Elastic::Model::Results',
-            cached_results   => 'Elastic::Model::Results::Cached',
             scrolled_results => 'Elastic::Model::Results::Scrolled',
             result           => 'Elastic::Model::Result',
-            bulk             => 'Elastic::Model::Bulk'
         };
     },
     handles => {
@@ -71,14 +72,6 @@ has 'classes' => (
     }
 );
 
-#===================================
-has 'unique_index' => (
-#===================================
-    is      => 'rw',
-    isa     => 'Str',
-    default => sub {'unique_key'}
-);
-
 no Moose;
 
 our %DefaultAnalysis = (
@@ -135,7 +128,7 @@ sub analysis_for_mappings {
         for my $name ( _required_analyzers( $mappings->{$type} ) ) {
             next
                 if exists $analyzers{$name}
-                || $self->is_default( 'analyzer', $name );
+                    || $self->is_default( 'analyzer', $name );
             $analyzers{$name} = $self->analyzer($name)
                 or die "Unknown analyzer ($name) required by type ($type)";
         }
@@ -150,7 +143,7 @@ sub analysis_for_mappings {
             for my $name ( ref $vals ? @$vals : $vals ) {
                 next
                     if exists $defn{$name}
-                    || $self->is_default( $type, $name );
+                        || $self->is_default( $type, $name );
                 $defn{$name} = $self->$type($name)
                     or die
                     "Unknown $type ($name) required by analyzer '$analyzer_name'";
@@ -188,9 +181,9 @@ sub wrapped_class_name {
 
 1;
 
-=pod
 
-=encoding UTF-8
+
+=pod
 
 =head1 NAME
 
@@ -198,7 +191,7 @@ Elastic::Model::Meta::Class::Model - A meta-class for Models
 
 =head1 VERSION
 
-version 0.29_2
+version 0.01
 
 =head1 DESCRIPTION
 
@@ -215,18 +208,18 @@ be accessible via L<Elastic::Model> or L<Elastic::Model::Role::Model>.
     $bool = $meta->is_default($type => $name);
 
 Returns C<true> if C<$name> is a C<$type> (analyzer, tokenizer,
-filter, char_filter) available in Elasticsearch by default.
+filter, char_filter) available in ElasticSearch by default.
 
 =head3 Default analyzers
 
-L<standard|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-standard-analyzer.html>,
-L<simple|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-simple-analyzer.html>,
-L<whitespace|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-whitespace-analyzer.html>,
-L<stop|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-stop-analyzer.html>,
-L<keyword|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-keyword-analyzer.html>,
-L<pattern|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-pattern-analyzer.html>,
-L<snowball|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-snowball-analyzer.html>,
-and the L<language|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-lang-analyzer.html>
+L<standard|http://www.elasticsearch.org/guide/reference/index-modules/analysis/standard-analyzer.html>,
+L<simple|http://www.elasticsearch.org/guide/reference/index-modules/analysis/simple-analyzer.html>,
+L<whitespace|http://www.elasticsearch.org/guide/reference/index-modules/analysis/whitespace-analyzer.html>,
+L<stop|http://www.elasticsearch.org/guide/reference/index-modules/analysis/stop-analyzer.html>,
+L<keyword|http://www.elasticsearch.org/guide/reference/index-modules/analysis/keyword-analyzer.html>,
+L<pattern|http://www.elasticsearch.org/guide/reference/index-modules/analysis/pattern-analyzer.html>,
+L<snowball|http://www.elasticsearch.org/guide/reference/index-modules/analysis/snowball-analyzer.html>,
+and the L<language|http://www.elasticsearch.org/guide/reference/index-modules/analysis/lang-analyzer.html>
 analyzers:  C<arabic>, C<armenian>, C<basque>, C<brazilian>, C<bulgarian>,
 C<catalan>, C<chinese>, C<cjk>, C<czech>, C<danish>, C<dutch>, C<english>,
 C<finnish>, C<french>, C<galician>, C<german>, C<greek>, C<hindi>, C<hungarian>,
@@ -236,49 +229,49 @@ C<thai>, C<turkish>
 
 =head3 Default tokenizers
 
-L<edge_ngram|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-edgengram-tokenizer.html>,
-L<keyword|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-keyword-tokenizer.html>,
-L<letter|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-letter-tokenizer.html>,
-L<lowercase|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-lowercase-tokenizer.html>,
-L<ngram|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-ngram-tokenizer.html>,
-L<path_hierarchy|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-pathhierarchy-tokenizer.html>,
-L<pattern|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-pattern-tokenizer.html>,
-L<standard|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-standard-tokenizer.html>,
-L<uax_url_email|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-uaxurlemail-tokenizer.html>,
-L<whitespace|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-whitespace-tokenizer.html>
+L<edge_ngram|http://www.elasticsearch.org/guide/reference/index-modules/analysis/edgengram-tokenizer.html>,
+L<keyword|http://www.elasticsearch.org/guide/reference/index-modules/analysis/keyword-tokenizer.html>,
+L<letter|http://www.elasticsearch.org/guide/reference/index-modules/analysis/letter-tokenizer.html>,
+L<lowercase|http://www.elasticsearch.org/guide/reference/index-modules/analysis/lowercase-tokenizer.html>,
+L<ngram|http://www.elasticsearch.org/guide/reference/index-modules/analysis/ngram-tokenizer.html>,
+L<path_hierarchy|http://www.elasticsearch.org/guide/reference/index-modules/analysis/pathhierarchy-tokenizer.html>,
+L<pattern|http://www.elasticsearch.org/guide/reference/index-modules/analysis/pattern-tokenizer.html>,
+L<standard|http://www.elasticsearch.org/guide/reference/index-modules/analysis/standard-tokenizer.html>,
+L<uax_url_email|http://www.elasticsearch.org/guide/reference/index-modules/analysis/uaxurlemail-tokenizer.html>,
+L<whitespace|http://www.elasticsearch.org/guide/reference/index-modules/analysis/whitespace-tokenizer.html>
 
 =head3 Default token filters
 
-L<asciifolding|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-asciifolding-tokenfilter.html>,
-L<dictionary_decompounder|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-compound-word-tokenfilter.html>,
-L<edge_ngram|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-edgengram-tokenfilter.html>,
-L<elision|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-elision-tokenfilter.html>,
-L<hyphenation_decompounder|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-compound-word-tokenfilter.html>,
-L<icu_collation|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-icu-plugin.html>,
-L<icu_folding|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-icu-plugin.html>,
-L<icu_normalizer|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-icu-plugin.html>,
-L<kstem|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-kstem-tokenfilter.html>,
-L<length|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-length-tokenfilter.html>,
-L<lowercase|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-lowercase-tokenfilter.html>,
-L<ngram|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-ngram-tokenfilter.html>,
-L<pattern_replace|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-pattern_replace-tokenfilter.html>,
-L<phonetic|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-phonetic-tokenfilter.html>,
-L<porterStem|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-porterstem-tokenfilter.html>,
-L<reverse|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-reverse-tokenfilter.html>,
-L<shingle|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-shingle-tokenfilter.html>,
-L<snowball|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-snowball-tokenfilter.html>,
-L<standard|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-standard-tokenfilter.html>,
-L<stop|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-stop-tokenfilter.html>,
-L<synonym|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-synonym-tokenfilter.html>,
-L<trim|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-trim-tokenfilter.html>,
-L<truncate|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-truncate-tokenfilter.html>,
-L<unique|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-word-delimiter-tokenfilter.html>,
-L<word_delimiter|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-word-delimiter-tokenfilter.html>
+L<asciifolding|http://www.elasticsearch.org/guide/reference/index-modules/analysis/asciifolding-tokenfilter.html>,
+L<dictionary_decompounder|http://www.elasticsearch.org/guide/reference/index-modules/analysis/compound-word-tokenfilter.html>,
+L<edge_ngram|http://www.elasticsearch.org/guide/reference/index-modules/analysis/edgengram-tokenfilter.html>,
+L<elision|http://www.elasticsearch.org/guide/reference/index-modules/analysis/elision-tokenfilter.html>,
+L<hyphenation_decompounder|http://www.elasticsearch.org/guide/reference/index-modules/analysis/compound-word-tokenfilter.html>,
+L<icu_collation|http://www.elasticsearch.org/guide/reference/index-modules/analysis/icu-plugin.html>,
+L<icu_folding|http://www.elasticsearch.org/guide/reference/index-modules/analysis/icu-plugin.html>,
+L<icu_normalizer|http://www.elasticsearch.org/guide/reference/index-modules/analysis/icu-plugin.html>,
+L<kstem|http://www.elasticsearch.org/guide/reference/index-modules/analysis/kstem-tokenfilter.html>,
+L<length|http://www.elasticsearch.org/guide/reference/index-modules/analysis/length-tokenfilter.html>,
+L<lowercase|http://www.elasticsearch.org/guide/reference/index-modules/analysis/lowercase-tokenfilter.html>,
+L<ngram|http://www.elasticsearch.org/guide/reference/index-modules/analysis/ngram-tokenfilter.html>,
+L<pattern_replace|http://www.elasticsearch.org/guide/reference/index-modules/analysis/pattern_replace-tokenfilter.html>,
+L<phonetic|http://www.elasticsearch.org/guide/reference/index-modules/analysis/phonetic-tokenfilter.html>,
+L<porterStem|http://www.elasticsearch.org/guide/reference/index-modules/analysis/porterstem-tokenfilter.html>,
+L<reverse|http://www.elasticsearch.org/guide/reference/index-modules/analysis/reverse-tokenfilter.html>,
+L<shingle|http://www.elasticsearch.org/guide/reference/index-modules/analysis/shingle-tokenfilter.html>,
+L<snowball|http://www.elasticsearch.org/guide/reference/index-modules/analysis/snowball-tokenfilter.html>,
+L<standard|http://www.elasticsearch.org/guide/reference/index-modules/analysis/standard-tokenfilter.html>,
+L<stop|http://www.elasticsearch.org/guide/reference/index-modules/analysis/stop-tokenfilter.html>,
+L<synonym|http://www.elasticsearch.org/guide/reference/index-modules/analysis/synonym-tokenfilter.html>,
+L<trim|http://www.elasticsearch.org/guide/reference/index-modules/analysis/trim-tokenfilter.html>,
+L<truncate|http://www.elasticsearch.org/guide/reference/index-modules/analysis/truncate-tokenfilter.html>,
+L<unique|http://www.elasticsearch.org/guide/reference/index-modules/analysis/word-delimiter-tokenfilter.html>,
+L<word_delimiter|http://www.elasticsearch.org/guide/reference/index-modules/analysis/word-delimiter-tokenfilter.html>
 
 =head3 Default character filters
 
-L<html_strip|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-htmlstrip-charfilter.html>,
-L<mapping|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/analysis-mapping-charfilter.html>
+L<html_strip|http://www.elasticsearch.org/guide/reference/index-modules/analysis/htmlstrip-charfilter.html>,
+L<mapping|http://www.elasticsearch.org/guide/reference/index-modules/analysis/mapping-charfilter.html>
 
 =head2 analysis_for_mappings()
 
@@ -313,16 +306,6 @@ A hash ref containing all namespaces plus their configuration, eg:
         }
     }
 
-=head2 unique_index
-
-    $index = $meta->unique_index
-
-The name of the index where unique keys will be stored, which defaults
-to C<unique_key>.  A different value can be specified with
-L<has_unique_index|Elastic::Model/Custom unique key index>.
-
-See L<Elastic::Manual::Attributes::Unique> for more.
-
 =head2 analyzers
 
     \%analyzers     = $meta->analyzers;
@@ -367,7 +350,7 @@ A hash ref containing all filters plus their configuration, eg:
 
     {
         my_filter => {
-            type        => 'edge_ngram',
+            type        => 'edgeNGram',
             min_gram    => 1,
             max_gram    => 20
         }
@@ -395,13 +378,14 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Clinton Gormley.
+This software is copyright (c) 2012 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
 __END__
 
 # ABSTRACT: A meta-class for Models
