@@ -1,5 +1,8 @@
 package Elastic::Model::Namespace;
-$Elastic::Model::Namespace::VERSION = '0.29_2'; # TRIAL
+{
+  $Elastic::Model::Namespace::VERSION = '0.01'; # TRIAL
+}
+
 use Moose;
 use MooseX::Types::Moose qw(Str HashRef ArrayRef);
 use Elastic::Model::Index();
@@ -43,7 +46,7 @@ sub all_domains {
 #===================================
     my $self    = shift;
     my @domains = ( $self->name, @{ $self->fixed_domains } );
-    my $aliases = $self->model->store->get_aliases( index => \@domains );
+    my $aliases = $self->model->es->get_aliases( index => \@domains );
     for ( keys %$aliases ) {
         push @domains, ( $_, keys %{ $aliases->{$_}{aliases} } );
     }
@@ -55,7 +58,7 @@ sub all_live_indices {
 #===================================
     my $self    = shift;
     my @domains = ( $self->name, @{ $self->fixed_domains } );
-    my $aliases = $self->model->store->get_aliases( index => \@domains );
+    my $aliases = $self->model->es->get_aliases( index => \@domains );
     return keys %$aliases;
 }
 
@@ -90,9 +93,9 @@ sub mappings {
 
 1;
 
-=pod
 
-=encoding UTF-8
+
+=pod
 
 =head1 NAME
 
@@ -100,7 +103,7 @@ Elastic::Model::Namespace - Class-to-type map
 
 =head1 VERSION
 
-version 0.29_2
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -134,7 +137,7 @@ version 0.29_2
 
 L<Elastic::Model::Namespace> maps your doc classes to
 L<types|Elastic::Manual::Terminology/Type> (like a database table) in
-Elasticsearch. For instance, you could map your class
+ElasticSearch. For instance, you could map your class
 C<MyApp::User> to type C<user>.
 
 This class <=> type mapping is applied to all
@@ -170,7 +173,7 @@ in a couple of places:
 
 A L<domain|Elastic::Model::Domain> is like a database handle - you need
 a domain to create, retrieve, update and deleted individual docs from
-Elasticsearch.  The L<domain name|Elastic::Model::Domain/name> can be an
+ElasticSearch.  The L<domain name|Elastic::Model::Domain/name> can be an
 L<index|Elastic::Manual::Terminology/Index> or an
 L<alias|Elastic::Manual::Terminology/Alias>.
 Several domains (indices/aliases) can be associated with a namespace.
@@ -198,7 +201,7 @@ so the ID must be unique across all indices in a namespace.
     @type_names = $namespace->all_types
     $class      = $namespace->class_for_type($type_name)
 
-A hashref whose keys are the type names in Elasticsearch, and whose
+A hashref whose keys are the type names in ElasticSearch, and whose
 values are wrapped doc classes, eg the class C<MyApp::User>
 wrapped by L<Elastic::Model::Role::Model/wrap_doc_class()>.
 
@@ -226,7 +229,7 @@ L</name> and L</all_domains()> for more.
     $index = $namespace->index('index_name');
 
 Creates an L<Elastic::Model::Index> object for creating and administering indices
-in the Elasticsearch cluster. The C<$index> L<name|Elastic::Model::Index/name>
+in the ElasticSearch cluster. The C<$index> L<name|Elastic::Model::Index/name>
 is either the L</name> of the C<$namespace> or the value passed in to L</index()>.
 
 =head2 alias()
@@ -235,7 +238,7 @@ is either the L</name> of the C<$namespace> or the value passed in to L</index()
     $alias = $namespace->alias('alias_name');
 
 Creates an L<Elastic::Model::Alias> object for creating and administering index
-aliases in the Elasticsearch cluster. The C<$alias> L<name|Elastic::Model::Alias/name>
+aliases in the ElasticSearch cluster. The C<$alias> L<name|Elastic::Model::Alias/name>
 is either the L</name> of the C<$namespace> or the value passed in to L</alias()>.
 
 =head2 all_domains()
@@ -250,7 +253,7 @@ L</fixed_domains> (if any).
 
     @indices = $namespace->all_live_indices();
 
-Queries Elasticsearch to find all existing indices related to the namespace
+Queries ElasticSearch to find all existing indices related to the namespace
 
 =head2 mappings()
 
@@ -288,13 +291,14 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Clinton Gormley.
+This software is copyright (c) 2012 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
 __END__
 
 # ABSTRACT: Class-to-type map
