@@ -1,10 +1,13 @@
 package Elastic::Model::Result;
-$Elastic::Model::Result::VERSION = '0.29_2'; # TRIAL
+{
+  $Elastic::Model::Result::VERSION = '0.01'; # TRIAL
+}
+
 use Moose;
 
 use Carp;
 use Elastic::Model::Types qw(UID);
-use MooseX::Types::Moose qw(HashRef Maybe Num Bool);
+use MooseX::Types::Moose qw(:all);
 
 use namespace::autoclean;
 
@@ -16,14 +19,6 @@ has 'result' => (
     required => 1,
 );
 
-#===================================
-has 'is_partial' => (
-#===================================
-    isa      => Bool,
-    is       => 'ro',
-    required => 1,
-);
-
 #===================================
 has 'uid' => (
 #===================================
@@ -81,32 +76,16 @@ has 'object' => (
     builder => '_build_object'
 );
 
-#===================================
-has 'partial' => (
-#===================================
-    is      => 'ro',
-    does    => 'Elastic::Model::Role::Doc',
-    lazy    => 1,
-    builder => '_build_partial'
-);
-
 no Moose;
 
 #===================================
 sub _build_uid    { Elastic::Model::UID->new_from_store( shift()->result ) }
+sub _build_source { shift->result->{_source} }
 sub _build_score  { shift->result->{_score} }
 sub _build_fields { shift->result->{fields} || {} }
 sub _build_highlights { shift->result->{highlight} || {} }
 #===================================
 
-#===================================
-sub _build_source {
-#===================================
-    my $self = shift;
-    return undef if $self->is_partial;
-    return $self->result->{_source};
-}
-
 #===================================
 sub _build_object {
 #===================================
@@ -117,16 +96,6 @@ sub _build_object {
     );
 }
 
-#===================================
-sub _build_partial {
-#===================================
-    my $self = shift;
-    $self->result->{_partial} ||= $self->model->new_partial_doc(
-        uid            => Elastic::Model::UID->new_partial( $self->result ),
-        partial_source => $self->result->{_source}
-    );
-}
-
 #===================================
 sub highlight {
 #===================================
@@ -145,7 +114,8 @@ sub explain {
     my $explain = $result->{_explanation}
         || return "No explanation\n";
 
-    my $text = sprintf "Doc: [%s|%s|%s], Shard: [%s|%d]:\n",
+    my $text = sprintf
+        "Doc: [%s|%s|%s], Shard: [%s|%d]:\n",
         map { defined $_ ? $_ : 'undef' }
         @{$result}{qw(_index _type _id _node _shard)};
 
@@ -178,9 +148,9 @@ sub explain {
 
 1;
 
-=pod
 
-=encoding UTF-8
+
+=pod
 
 =head1 NAME
 
@@ -188,7 +158,7 @@ Elastic::Model::Result - A wrapper for individual search results
 
 =head1 VERSION
 
-version 0.29_2
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -196,7 +166,6 @@ version 0.29_2
 
     $object             = $result->object;
     $uid                = $result->uid;
-    $partial_obj        = $result->partial;
 
     \%all_highlights    = $result->highlights;
     @field_highlights   = $result->highlight('field_name');
@@ -213,8 +182,7 @@ version 0.29_2
 =head1 DESCRIPTION
 
 L<Elastic::Model::Result> wraps the individual result returned from
-L<Elastic::Model::Results>, L<Elastic::Model::Results::Cached>
-or L<Elastic::Model::Results::Scrolled>.
+L<Elastic::Model::Results> or L<Elastic::Model::Results::Scrolled>.
 
 =head1 ATTRIBUTES
 
@@ -226,7 +194,7 @@ The object associated with the result.  By default, the L</source> field is
 returned in search results, meaning that we can inflate the object directly from
 the search results.  B<Note:> If you set L<Elastic::Model::View/fields> and you
 don't include C<'_source'> then you will be unable to inflate your object
-without a separate (but automatic) step to retrieve it from Elasticsearch.
+without a separate (but automatic) step to retrieve it from ElasticSearch.
 
 Also see L<Elastic::Manual::Scoping>.
 
@@ -244,17 +212,6 @@ The L<uid|Elastic::Model::UID> of the doc.  L<index|Elastic::Model::UID/index>,
 L<type|Elastic::Model::UID/type>, L<id|Elastic::Model::UID/id>
 and L<routing|Elastic::Model::UID/routing> are provided for convenience.
 
-=head2 partial
-
-    $partial_obj = $result->partial_object();
-
-If your objects are large, you may want to load only part of the object in your
-search results. You can specify which parts of the object to include or exclude
-using L<Elastic::Model::View/"include_paths / exclude_paths">.
-
-The partial objects returned by L</partial> function exactly as real objects,
-except that they cannot be saved.
-
 =head2 highlights
 
 =head2 highlight
@@ -316,18 +273,18 @@ L<http://www.lucenetutorial.com/advanced-topics/scoring.html>.
 
     \%raw_result = $result->result
 
-The raw result hashref as returned by Elasticsearch.
+The raw result hashref as returned by ElasticSearch.
 
 =head2 source
 
     \%source_field = $result->source
 
 The C<_source> field (ie the hashref which represents your object in
-Elasticsearch). This value is returned by default with any search, and is
+ElasticSearch). This value is returned by default with any search, and is
 used to inflate your L</object> without having to retrieve it in a separate
 step. B<Note:> If you set L<Elastic::Model::View/fields> and you don't include
 C<'_source'> then you will be unable to inflate your object without a separate
-(but automatic) step to retrieve it from Elasticsearch.
+(but automatic) step to retrieve it from ElasticSearch.
 
 =head1 AUTHOR
 
@@ -335,13 +292,14 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Clinton Gormley.
+This software is copyright (c) 2012 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
 __END__
 
 # ABSTRACT: A wrapper for individual search results
