@@ -1,9 +1,12 @@
 package Elastic::Model::Results;
-$Elastic::Model::Results::VERSION = '0.29_2'; # TRIAL
+{
+  $Elastic::Model::Results::VERSION = '0.01'; # TRIAL
+}
+
 use Carp;
 use Moose;
 with 'Elastic::Model::Role::Results';
-use MooseX::Types::Moose qw(Num);
+use MooseX::Types::Moose qw(:all);
 
 use namespace::autoclean;
 
@@ -20,9 +23,7 @@ no Moose;
 #===================================
 sub BUILD {
 #===================================
-    my $self = shift;
-    return if $_[0]->{elements};
-
+    my $self   = shift;
     my $result = $self->model->search( $self->search );
 
     my $hits = $result->{hits};
@@ -33,13 +34,14 @@ sub BUILD {
     $self->_set_took( $result->{took} || 0 );
     $self->_set_facets( $result->{facets} || {} );
 
+    #$self->_set_timed_out( !!$result->{timed_out} );
 }
 
 1;
 
-=pod
 
-=encoding UTF-8
+
+=pod
 
 =head1 NAME
 
@@ -47,7 +49,7 @@ Elastic::Model::Results - An iterator over bounded/finite search results
 
 =head1 VERSION
 
-version 0.29_2
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -150,15 +152,15 @@ The number of L</elements> in the C<$results> object;
 
     $total_matching = $results->total
 
-The total number of matching docs found by Elasticsearch.  This is
+The total number of matching docs found by ElasticSearch.  This is
 distinct from the L</size> which contains the number of results RETURNED
-by Elasticsearch.
+by ElasticSearch.
 
 =head2 max_score
 
     $max_score = $results->max_score
 
-The highest score (relevance) found by Elasticsearch. B<Note:> if you
+The highest score (relevance) found by ElasticSearch. B<Note:> if you
 are sorting by a field other than C<_score> then you will need
 to set L<Elastic::Model::View/track_scores> to true to retrieve the
 L</max_score>.
@@ -281,14 +283,7 @@ eg C<MyApp::User>
     $results->as_elements()
 
 Sets the "short" accessors (eg L</next>, L</prev>) to return the raw result
-returned by Elasticsearch.
-
-=head2 as_partials()
-
-    $results->as_partials()
-
-Sets the "short" accessors (eg L</next>, L</prev>) to return partial objects
-as specified by L<Elastic::Model::View/"include_paths / exclude_paths">.
+returned by ElasticSearch.
 
 =head1 ELEMENT ACCESSORS
 
@@ -308,12 +303,7 @@ an instance of C<MyApp::User>
 
 =item *
 
-Element, eg C<next_element> which returns the raw hashref from Elasticsearch
-
-=item *
-
-Partial Doc, eg C<next_partial> which returns a partial object as specified
-by L<Elastic::Model::View/"include_paths / exclude_paths">.
+Element, eg C<next_element> which returns the raw hashref from ElasticSearch
 
 =item *
 
@@ -337,7 +327,7 @@ Returns the first element, and resets the iterator so that a call
 to L</next> will return the second element. If there is
 no first element, it returns undef.
 
-Also C<first_result>, C<first_object>, C<first_element>, C<first_partial>
+Also C<first_result>, C<first_object>, C<first_element>
 
 =head2 next
 
@@ -351,7 +341,7 @@ element, then it will work like this:
     $results->next;        # returns undef, and resets iterator
     $results->next;        # returns first element
 
-Also C<next_result>, C<next_object>, C<next_element>, C<next_partial>
+Also C<next_result>, C<next_object>, C<next_element>
 
 =head2 prev
 
@@ -365,7 +355,7 @@ first element, then it will work like this:
     $results->prev;        # returns undef, and resets iterator to end
     $results->prev;        # returns last element
 
-Also C<prev_result>, C<prev_object>, C<prev_element>, C<prev_partial>
+Also C<prev_result>, C<prev_object>, C<prev_element>
 
 =head2 current
 
@@ -373,7 +363,7 @@ Also C<prev_result>, C<prev_object>, C<prev_element>, C<prev_partial>
 
 Returns the current element, or undef
 
-Also C<current_result>, C<current_object>, C<current_element>, C<current_partial>
+Also C<current_result>, C<current_object>, C<current_element>
 
 =head2 last
 
@@ -384,7 +374,7 @@ to L</next> will return undef, and a second call to
 L</next> will return the first element If there is
 no last element, it returns undef.
 
-Also C<last_result>, C<last_object>, C<last_element>, C<last_partial>
+Also C<last_result>, C<last_object>, C<last_element>
 
 =head2 peek_next
 
@@ -392,8 +382,7 @@ Also C<last_result>, C<last_object>, C<last_element>, C<last_partial>
 
 Returns the next element (or undef), but doesn't move the iterator.
 
-Also C<peek_next_result>, C<peek_next_object>, C<peek_next_element>,
-C<peek_next_partial>
+Also C<peek_next_result>, C<peek_next_object>, C<peek_next_element>
 
 =head2 peek_prev
 
@@ -401,8 +390,7 @@ C<peek_next_partial>
 
 Returns the previous element (or undef), but doesn't move the iterator.
 
-Also C<peek_prev_result>, C<peek_prev_object>, C<peek_prev_element>,
-C<peek_prev_partial>
+Also C<peek_prev_result>, C<peek_prev_object>, C<peek_prev_element>
 
 =head2 shift
 
@@ -411,7 +399,7 @@ C<peek_prev_partial>
 Returns the L</first> element and removes it from from the list. L</size>
 will decrease by 1. Returns undef if there are no more elements.
 
-Also C<shift_result>, C<shift_object>, C<shift_element>, C<shift_partial>
+Also C<shift_result>, C<shift_object>, C<shift_element>
 
 =head2 slice
 
@@ -431,7 +419,7 @@ If your iterator only contains 5 elements:
     $results->slice(3,10);         # elements 3..4
     $results->slice(10,10);        # an empty list
 
-Also C<slice_results>, C<slice_objects>, C<slice_elements>, C<slice_partials>
+Also C<slice_results>, C<slice_objects>, C<slice_elements>
 
 =head2 all
 
@@ -439,7 +427,7 @@ Also C<slice_results>, C<slice_objects>, C<slice_elements>, C<slice_partials>
 
 Returns all L</elements> as a list.
 
-Also C<all_results>, C<all_objects>, C<all_elements>, C<all_partials>
+Also C<all_results>, C<all_objects>, C<all_elements>
 
 =head1 AUTHOR
 
@@ -447,13 +435,14 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Clinton Gormley.
+This software is copyright (c) 2012 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
 __END__
 
 # ABSTRACT: An iterator over bounded/finite search results
