@@ -1,16 +1,19 @@
 package Elastic::Model::Results::Scrolled;
-$Elastic::Model::Results::Scrolled::VERSION = '0.29_2'; # TRIAL
+{
+  $Elastic::Model::Results::Scrolled::VERSION = '0.01'; # TRIAL
+}
+
 use Carp;
 use Moose;
 with 'Elastic::Model::Role::Results';
-use MooseX::Types::Moose qw(Int);
+use MooseX::Types::Moose qw(:all);
 
 use namespace::autoclean;
 
 #===================================
 has '_scroll' => (
 #===================================
-    isa    => 'Search::Elasticsearch::Scroll',
+    isa    => 'ElasticSearch::ScrolledSearch',
     is     => 'ro',
     writer => '_set_scroll',
 );
@@ -69,7 +72,7 @@ sub _fetch_until {
     my $i        = shift || 0;
     my $scroll   = $self->_scroll;
     my $elements = $self->elements;
-    while ( $i >= @$elements and not $scroll->is_finished ) {
+    while ( $i >= @$elements and not $scroll->eof ) {
         push @$elements, $scroll->drain_buffer;
         $scroll->refill_buffer;
     }
@@ -77,9 +80,9 @@ sub _fetch_until {
 
 1;
 
-=pod
 
-=encoding UTF-8
+
+=pod
 
 =head1 NAME
 
@@ -87,7 +90,7 @@ Elastic::Model::Results::Scrolled - An iterator over unbounded search results
 
 =head1 VERSION
 
-version 0.29_2
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -109,7 +112,7 @@ All active users:
 An L<Elastic::Model::Results::Scrolled> object is returned when you call
 L<Elastic::Model::View/scroll()> or L<Elastic::Model::View/scan()>,
 and is intended for searches that could potentially retrieve many results.
-Results are retrieved from Elasticsearch in chunks.
+Results are retrieved from ElasticSearch in chunks.
 
 A C<$results> object can iterate through L<Elastic::Model::Result> objects
 (with all the result metadata), or just the DocClass object itself
@@ -151,13 +154,13 @@ will decrease, while the L</total> will remain the same.
 
     $total_matching = $results->total
 
-The total number of matching docs found by Elasticsearch.
+The total number of matching docs found by ElasticSearch.
 
 =head2 max_score
 
     $max_score = $results->max_score
 
-The highest score (relevance) found by Elasticsearch. B<Note:> if you
+The highest score (relevance) found by ElasticSearch. B<Note:> if you
 are sorting by a field other than C<_score> then you will need
 to set L<Elastic::Model::View/track_scores> to true to retrieve the
 L</max_score>.
@@ -280,7 +283,7 @@ eg C<MyApp::User>
     $results->as_elements()
 
 Sets the "short" accessors (eg L</next>, L</prev>) to return the raw result
-returned by Elasticsearch.
+returned by ElasticSearch.
 
 =head1 ELEMENT ACCESSORS
 
@@ -300,7 +303,7 @@ an instance of C<MyApp::User>
 
 =item *
 
-Element, eg C<next_element> which returns the raw hashref from Elasticsearch
+Element, eg C<next_element> which returns the raw hashref from ElasticSearch
 
 =item *
 
@@ -432,13 +435,14 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Clinton Gormley.
+This software is copyright (c) 2012 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
 __END__
 
 # ABSTRACT: An iterator over unbounded search results
