@@ -1,5 +1,8 @@
 package Elastic::Model::Role::Doc;
-$Elastic::Model::Role::Doc::VERSION = '0.29_2'; # TRIAL
+{
+  $Elastic::Model::Role::Doc::VERSION = '0.01'; # TRIAL
+}
+
 use Moose::Role;
 
 use Elastic::Model::Trait::Exclude;
@@ -20,7 +23,6 @@ has 'uid' => (
     writer   => '_set_uid',
     traits   => ['Elastic::Model::Trait::Exclude'],
     exclude  => 1,
-    handles  => [ 'id', 'type' ]
 );
 
 #===================================
@@ -54,55 +56,48 @@ has '_source' => (
     writer  => '_set_source',
 );
 
+#===================================
+has '_old_value' => (
+#===================================
+    is        => 'ro',
+    isa       => HashRef,
+    traits    => ['Elastic::Model::Trait::Exclude'],
+    exclude   => 1,
+    writer    => '_set_old_value',
+    clearer   => '_clear_old_value',
+    predicate => '_has_old_value'
+);
+
 no Moose::Role;
 
 #===================================
 sub has_changed {
 #===================================
     my $self = shift;
-    my $old  = $self->old_values;
-    return '' unless keys %$old;
-    return @_
-        ? exists $old->{ $_[0] }
-        : 1;
-}
-
-#===================================
-sub old_values {
-#===================================
-    my $self = shift;
-    return {} if $self->_can_inflate;
-    my $current  = $self->model->deflate_object($self);
-    my %original = %{ $self->uid->from_store ? $self->_source : {} };
-    my $json     = $self->model->json;
-    my %old;
-
-    my ( $o, $c, $o_str, $c_str );
-    my $meta  = Class::MOP::class_of($self);
-    my $model = $self->model;
-    for my $key ( keys %$current ) {
-        unless ( exists $original{$key} ) {
-            $old{$key} = undef;
-            next;
-        }
-        no warnings 'uninitialized';
-        ( $o, $c ) = ( delete $original{$key}, $current->{$key} );
-        ( $o_str, $c_str )
-            = map { ref $_ ? $json->encode($_) : $_ } ( $o, $c );
-
-        if ( $o_str ne $c_str ) {
-            $old{$key} = $meta->inflator_for( $model, $key )->($o);
+    if (@_) {
+        my $attr = shift;
+        my $old = $self->_old_value || {};
+        if ( $attr eq "1" or @_ ) {
+            $old->{$attr} = shift()
+                unless $attr eq "1" || exists $old->{$attr};
+            $self->_set_old_value($old);
+            return 1;
         }
+        return exists $old->{$attr};
     }
-    $old{$_} = $meta->inflator_for( $model, $_ )->( $original{$_} )
-        for keys %original;
-    return \%old;
+    return $self->_has_old_value;
 }
 
+#===================================
+sub old_values { shift->_old_value || {} }
+#===================================
+
 #===================================
 sub old_value {
 #===================================
-    die('old_value($attr) has been removed. Use old_values->{$attr} instead');
+    my $self = shift;
+    my $attr = shift or croak "No (attr) passed to old_value()";
+    return $self->old_values->{$attr};
 }
 
 #===================================
@@ -110,8 +105,8 @@ sub _get_source {
 #===================================
     my $self = shift;
     $self->model->get_doc_source(
-        uid    => $self->uid,
-        ignore => 404,
+        uid            => $self->uid,
+        ignore_missing => 1,
         @_
     );
 }
@@ -124,13 +119,12 @@ sub _inflate_doc {
         or return bless( $self, 'Elastic::Model::Deleted' )->croak;
 
     $self->_can_inflate(0);
-    eval {
+    try {
         $self->model->inflate_object( $self, $source );
-        1;
-    } or do {
-        my $error = $@;
+    }
+    catch {
         $self->_can_inflate(1);
-        die $error;
+        die $_;
     };
 }
 
@@ -147,9 +141,10 @@ sub save {
 #===================================
     my $self = shift;
 
-    unless ( $self->_can_inflate ) {
+    if ( $self->has_changed || !$self->uid->from_store ) {
         $self->touch;
-        $self->model->save_doc( doc => $self, @_ );
+        $self->model->save_doc( doc => $self, @_ )
+            and $self->_clear_old_value;
     }
     $self;
 }
@@ -176,25 +171,11 @@ sub has_been_deleted {
     !$self->model->doc_exists( uid => $uid, @_ );
 }
 
-#===================================
-sub terms_indexed_for_field {
-#===================================
-    my $self  = shift;
-    my $field = shift or croak "Missing required param (fieldname)";
-    my $size  = shift || 20;
-
-    my $uid = $self->uid;
-    return $self->model->view->domain( $uid->index )->type( $uid->type )
-        ->filterb( _id => $uid->id )
-        ->facets( field => { terms => { field => $field, size => 20 } } )
-        ->size(0)->search->facet('field');
-}
-
 1;
 
-=pod
 
-=encoding UTF-8
+
+=pod
 
 =head1 NAME
 
@@ -202,7 +183,7 @@ Elastic::Model::Role::Doc - The role applied to your Doc classes
 
 =head1 VERSION
 
-version 0.29_2
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -231,7 +212,7 @@ version 0.29_2
     print $doc->has_changed();              # 1
     print $doc->has_changed('name');        # 1
     print $doc->has_changed('email');       # 0
-    dump $doc->old_values;                  # { name => 'Clint' }
+    print $doc->old_value('name');          # Clint
 
     $doc->save;
     print $doc->has_changed();              # 0
@@ -244,7 +225,7 @@ version 0.29_2
 =head1 DESCRIPTION
 
 L<Elastic::Model::Role::Doc> is applied to your "doc" classes (ie those classes
-that you want to be stored in Elasticsearch), when you include this line:
+that you want to be stored in ElasticSearch), when you include this line:
 
     use Elastic::Doc;
 
@@ -258,10 +239,10 @@ The following attributes are added to your class:
 =head2 uid
 
 The L<uid|Elastic::Model::UID> is the unique identifier for your doc in
-Elasticsearch. It contains an L<index|Elastic::Model::UID/"index">,
+ElasticSearch. It contains an L<index|Elastic::Model::UID/"index">,
 a L<type|Elastic::Model::UID/"type">, an L<id|Elastic::Model::UID/"id"> and
 possibly a L<routing|Elastic::Model::UID/"routing">. This is what is required
-to identify your document uniquely in Elasticsearch.
+to identify your document uniquely in ElasticSearch.
 
 The UID is created when you create your document, eg:
 
@@ -287,38 +268,17 @@ L<new_doc()|Elastic::Model::Domain/"new_doc()"> (C<user> in this case).
 =item *
 
 C<id> : is optional - if you don't provide it, then it will be
-auto-generated when you save it to Elasticsearch.
+auto-generated when you save it to ElasticSearch.
 
 =back
 
 B<Note:> the C<namespace_name/type/ID> of a document must be unique.
-Elasticsearch can enforce uniqueness for a single index, but when your
+ElasticSearch can enforce uniqueness for a single index, but when your
 L<namespace|Elastic::Model::Namespace> contains multiple indices, it is up
 to you to ensure uniqueness.  Either leave the ID blank, in which case
-Elasticsearch will generate a unique ID, or ensure that the way you
+ElasticSearch will generate a unique ID, or ensure that the way you
 generate IDs will not cause a collision.
 
-=head2 type / id
-
-    $type = $doc->type;
-    $id   = $doc->id;
-
-C<type> and C<id> are provided as convenience, read-only accessors which
-call the equivalent accessor on L</uid>.
-
-You can defined your own C<id()> and C<type()> methods, in which case they
-won't be imported, or you can import them under a different name, eg:
-
-    package MyApp::User;
-    use Elastic::Doc;
-
-    with 'Elastic::Model::Role::Doc' => {
-        -alias => {
-            id   => 'doc_id',
-            type => 'doc_type',
-        }
-    };
-
 =head2 timestamp
 
     $timestamp = $doc->timestamp($timestamp);
@@ -339,7 +299,12 @@ inflated already or not.
 
 =head3 _source
 
-The raw uninflated source value as loaded from Elasticsearch.
+The raw uninflated source value as loaded from ElasticSearch.
+
+=head3 _old_value
+
+If any attribute value has changed, the original value will be stored in
+C<_old_value>. See L</"old_value()"> and L</"has_changed()">.
 
 =head1 METHODS
 
@@ -347,14 +312,12 @@ The raw uninflated source value as loaded from Elasticsearch.
 
     $doc->save( %args );
 
-Saves the C<$doc> to Elasticsearch. If this is a new doc, and a doc with the
-same type and ID already exists in the same index, then Elasticsearch
+Saves the C<$doc> to ElasticSearch. If this is a new doc, and a doc with the
+same type and ID already exists in the same index, then ElasticSearch
 will throw an exception.
 
-Also see L<Elastic::Model::Bulk> for bulk indexing of multiple docs.
-
-If the doc was previously loaded from Elasticsearch, then that doc will be
-updated. However, because Elasticsearch uses
+If the doc was previously loaded from ElasticSearch, then that doc will be
+updated. However, because ElasticSearch uses
 L<optimistic locking|http://en.wikipedia.org/wiki/Optimistic_locking>
 (ie the doc version number is incremented on every change), it is possible that
 another process has already updated the C<$doc> while the current process has
@@ -372,7 +335,7 @@ For instance:
 
 =head3 on_conflict
 
-If you don't care, and you just want to overwrite what is stored in Elasticsearch
+If you don't care, and you just want to overwrite what is stored in ElasticSearch
 with the current values, then use L</overwrite()> instead of L</save()>. If you
 DO care, then you can handle this situation gracefully, using the
 C<on_conflict> parameter:
@@ -392,32 +355,13 @@ on a doc that hasn't changed, then you can do:
 
     $doc->touch->save;
 
-=head3 on_unique
-
-If you have any L<unique attributes|Elastic::Manual::Attributes/unique_key> then
-you can catch unique-key conflicts with the C<on_unique> handler.
-
-    $doc->save(
-        on_unique => sub {
-            my ($doc,$conflicts) = @_;
-            # do something
-        }
-    )
-
-The C<$conflicts> hashref will contain a hashref whose keys are the name
-of the L<unique_keys|Elastic::Manual::Attributes/unique_key> that have
-conflicts, and whose values are the values of those keys which already exist,
-and so cannot be overwritten.
-
-See L<Elastic::Manual::Attributes::Unique> for more.
-
 =head2 overwrite()
 
     $doc->overwrite( %args );
 
 L</overwrite()> is exactly the same as L</save()> except it will overwrite
-any previous doc, regardless of whether another process has created or updated
-a doc with the same UID in the meantime.
+any previous doc, regardless of whether another process has updated the same
+doc in the meantime.
 
 =head2 delete()
 
@@ -441,7 +385,7 @@ your application, otherwise you have to wrap all of your code in C<eval>s
 to ensure that you're not accessing a stale doc.
 
 However, if you do need to delete current docs, then L</has_been_deleted()>
-checks if the doc exists in Elasticsearch.  For instance, you
+checks if the doc exists in ElasticSearch.  For instance, you
 might have an L</on_conflict> handler which looks like this:
 
     $doc->save(
@@ -451,7 +395,7 @@ might have an L</on_conflict> handler which looks like this:
             return $original->overwrite
                 if $new->has_been_deleted;
 
-            for my $attr ( keys %{ $old->old_values }) {
+            for my $attr ( keys %{ $old->old_value }) {
                 $new->$attr( $old->$attr ):
             }
 
@@ -479,25 +423,23 @@ Has the value of attribute C<$attr_name> changed?
 
     $bool = $doc->has_changed($attr_name);
 
-B<Note:> If you're going to check more than one attribute, rather get
-all the L</old_values()> and check if the attribute name exists in the
-returned hash, rather than calling L<has_changed()> multiple times.
+Mark the object as changed without specifying an attribute:
+
+    $doc->has_changed(1);
 
 =head2 old_values()
 
     \%old_vals  = $doc->old_values();
 
 Returns a hashref containing the original values of any attributes that have
-been changed. If an attribute wasn't set originally, but is now, it will
-be included in the hash with the value C<undef>.
+been changed.
 
-=head2 terms_indexed_for_field()
+=head2 old_value()
 
-    $terms = $doc->terms_indexed_for_field( $fieldname, $size );
+    $old_val    = $doc->old_value($attr_name);
 
-This method is useful for debugging queries and analysis - it returns
-the actual terms (ie after analysis) that have been indexed for
-field C<$fieldname> in the current doc. C<$size> defaults to 20.
+Returns the original value that an attribute had before being changed, or
+C<undef>.
 
 =head2 Private methods
 
@@ -510,7 +452,11 @@ Inflates the attribute values from the hashref stored in L</"_source">.
 
 =head3 _get_source / _set_source
 
-The raw doc source from Elasticsearch.
+The raw doc source from ElasticSearch.
+
+=head3 _set_old_value / _clear_old_value / _has_old_value
+
+Accessors for L</"_old_value">.
 
 =head1 AUTHOR
 
@@ -518,13 +464,14 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Clinton Gormley.
+This software is copyright (c) 2012 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
 __END__
 
 # ABSTRACT: The role applied to your Doc classes
