@@ -1,5 +1,8 @@
 package Elastic::Model::Role::Index;
-$Elastic::Model::Role::Index::VERSION = '0.29_2'; # TRIAL
+{
+  $Elastic::Model::Role::Index::VERSION = '0.01'; # TRIAL
+}
+
 use Moose::Role;
 use MooseX::Types::Moose qw(Str);
 use Carp;
@@ -22,8 +25,21 @@ has 'namespace' => (
     handles => [ 'model', 'mappings' ]
 );
 
+#===================================
+has 'es' => (
+#===================================
+    is      => 'ro',
+    isa     => 'ElasticSearch',
+    lazy    => 1,
+    builder => '_build_es'
+);
+
 no Moose::Role;
 
+#===================================
+sub _build_es { shift->model->es }
+#===================================
+
 #===================================
 sub index_config {
 #===================================
@@ -49,7 +65,7 @@ sub delete  { shift->_index_action( 'delete_index',  @_ ) }
 sub refresh { shift->_index_action( 'refresh_index', @_ ) }
 sub open    { shift->_index_action( 'open_index',    @_ ) }
 sub close   { shift->_index_action( 'close_index',   @_ ) }
-sub exists { !!$_[0]->model->store->index_exists( index => $_[0]->name ) }
+sub exists { !!$_[0]->es->index_exists( index => $_[0]->name ) }
 #===================================
 
 #===================================
@@ -58,7 +74,7 @@ sub _index_action {
     my $self   = shift;
     my $action = shift;
     my %args   = @_;
-    $self->model->store->$action( %args, index => $self->name );
+    $self->es->$action( %args, index => $self->name );
     return $self;
 }
 
@@ -66,7 +82,7 @@ sub _index_action {
 sub update_settings {
 #===================================
     my $self = shift;
-    $self->model->store->update_index_settings(
+    $self->es->update_index_settings(
         index    => $self->name,
         settings => {@_}
     );
@@ -79,7 +95,7 @@ sub update_analyzers {
     my $self   = shift;
     my $params = $self->index_config(@_);
     delete $params->{mappings};
-    $self->model->store->update_index_settings(%$params);
+    $self->es->update_index_settings($params);
     return $self;
 }
 
@@ -88,33 +104,30 @@ sub is_alias {
 #===================================
     my $self    = shift;
     my $name    = $self->name;
-    my $indices = $self->model->store->get_aliases( index => $name );
+    my $indices = $self->es->get_aliases( index => $name );
     return !!( %$indices && !$indices->{$name} );
 }
 
 #===================================
 sub is_index {
 #===================================
-    my $self    = shift;
-    my $name    = $self->name;
-    my $indices = $self->model->store->get_aliases( index => $name );
-    return !!$indices->{$name};
+    my $self = shift;
+    my $name = $self->name;
+    return !!$self->es->get_aliases( index => $name )->{$name};
 }
 
 #===================================
 sub update_mapping {
 #===================================
     my $self     = shift;
-    my %args     = ref $_[-1] eq 'HASH' ? %{ pop() } : ();
     my $mappings = $self->mappings(@_);
-    my $store    = $self->model->store;
+    my $es       = $self->es;
     my $name     = $self->name;
     for my $type ( keys %$mappings ) {
-        $store->put_mapping(
+        $es->put_mapping(
             index   => $name,
             type    => $type,
-            mapping => $mappings->{$type},
-            %args,
+            mapping => $mappings->{$type}
         );
     }
     return $self;
@@ -123,19 +136,18 @@ sub update_mapping {
 #===================================
 sub delete_mapping {
 #===================================
-    my $self  = shift;
-    my %args  = ref $_[-1] eq 'HASH' ? %{ pop() } : ();
-    my $store = $self->model->store;
-    my $name  = $self->name;
-    $store->delete_mapping( index => $name, type => $_, %args ) for @_;
+    my $self = shift;
+    my $es   = $self->es;
+    my $name = $self->name;
+    $es->delete_mapping( index => $name, type => $_ ) for @_;
     return $self;
 }
 
 1;
 
-=pod
 
-=encoding UTF-8
+
+=pod
 
 =head1 NAME
 
@@ -143,7 +155,7 @@ Elastic::Model::Role::Index - Provides admin methods common to indices and alias
 
 =head1 VERSION
 
-version 0.29_2
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -191,7 +203,7 @@ L<Elastic::Model::Index> or L<Elastic::Model::Alias> object.
 
 =head2 es
 
-The same L<Search::Elasticsearch::Compat> connection as L<Elastic::Model::Role::Model/es>.
+The same L<ElasticSearch> connection as L<Elastic::Model::Role::Model/es>.
 
 =head1 METHODS
 
@@ -201,10 +213,10 @@ The same L<Search::Elasticsearch::Compat> connection as L<Elastic::Model::Role::
     $admin = $admin->delete( %args );
 
 Deletes the index (or indices pointed to by alias ) L</name>. Any
-C<%args> are passed directly to L<Search::Elasticsearch::Compat/delete_index()>.
+C<%args> are passed directly to L<ElasticSearch/delete_index()>.
 For example:
 
-    $admin->delete( ignore => 404 );
+    $admin->delete( ignore_missing => 1 );
 
 =head2 refresh()
 
@@ -243,7 +255,7 @@ L<Elastic::Model::Index/create_index()>.
 
     $admin = $admin->update_settings( %settings );
 
-Updates the L<index settings|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/indices-update-settings.html>
+Updates the L<index settings|http://www.elasticsearch.org/guide/reference/api/admin-indices-update-settings.html>
 for the the index (or indices pointed to by alias ) L</name>.
 
 For example, if you want to rebuild an index, you could disable refresh
@@ -269,7 +281,6 @@ L</namespace>.
 
     $admin = $admin->update_mapping();
     $admin = $admin->update_mapping( @type_names );
-    $admin = $admin->update_mapping( @type_names, { ignore_conflicts=> 1 } );
 
 Type mappings B<cannot be changed> on an existing index, but they B<can be
 added to>.  L</update_mapping()> will generate a new type mapping from your
@@ -281,19 +292,12 @@ update all types known to the L</namespace>.
 
     $admin->update_mapping( 'user','post');
 
-Any optional args passed
-as a hashref as the final parameter will be passed to
-L<Search::Elasticsearch::Compat/put_mapping()>
-
 =head2 delete_mapping();
 
     $admin = $admin->delete_mapping( @types );
-    $admin = $admin->delete_mapping( @types, { ignore => 404 });
 
 Deletes the type mapping B<AND THE DOCUMENTS> for the listed types in the index
-(or the indices pointed to by alias) L</name>. Any optional args passed
-as a hashref as the final parameter will be passed to
-L<Search::Elasticsearch::Compat/delete_mapping()>.
+(or the indices pointed to by alias) L</name>.
 
 =head2 exists()
 
@@ -342,13 +346,14 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Clinton Gormley.
+This software is copyright (c) 2012 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
 __END__
 
 # ABSTRACT: Provides admin methods common to indices and aliases
