@@ -1,8 +1,12 @@
 package Elastic::Model::Role::Iterator;
-$Elastic::Model::Role::Iterator::VERSION = '0.29_2'; # TRIAL
+{
+  $Elastic::Model::Role::Iterator::VERSION = '0.01'; # TRIAL
+}
+
 use Carp;
 use Moose::Role;
-use MooseX::Types::Moose qw(ArrayRef Int CodeRef);
+use MooseX::Types::Moose qw(:all);
+use MooseX::Attribute::Chained;
 use namespace::autoclean;
 
 #===================================
@@ -36,9 +40,7 @@ has 'wrapper' => (
     isa     => CodeRef,
     is      => 'rw',
     lazy    => 1,
-    default => sub {
-        sub { shift() }
-    },
+    default => sub { shift() },
 );
 
 #===================================
@@ -47,9 +49,7 @@ has 'multi_wrapper' => (
     isa     => CodeRef,
     is      => 'rw',
     lazy    => 1,
-    default => sub {
-        sub {@_}
-    },
+    default => sub {@_},
 );
 
 #===================================
@@ -338,9 +338,9 @@ sub _fetch_until { }
 
 1;
 
-=pod
 
-=encoding UTF-8
+
+=pod
 
 =head1 NAME
 
@@ -348,7 +348,7 @@ Elastic::Model::Role::Iterator - A generic iterator role
 
 =head1 VERSION
 
-version 0.29_2
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -625,13 +625,14 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Clinton Gormley.
+This software is copyright (c) 2012 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
 __END__
 
 # ABSTRACT: A generic iterator role
