@@ -1,9 +1,12 @@
 package Elastic::Model::Role::Model;
-$Elastic::Model::Role::Model::VERSION = '0.29_2'; # TRIAL
+{
+  $Elastic::Model::Role::Model::VERSION = '0.01'; # TRIAL
+}
+
 use Moose::Role;
 use Carp;
 use Elastic::Model::Types qw(ES);
-use Search::Elasticsearch 1.12 ();
+use ElasticSearch 0.55 ();
 use Class::Load qw(load_class);
 use Moose::Util qw(does_role);
 use MooseX::Types::Moose qw(:all);
@@ -11,13 +14,11 @@ use Elastic::Model::UID();
 use Elastic::Model::Deleted();
 use Scalar::Util qw(blessed refaddr weaken);
 use List::MoreUtils qw(uniq);
-use JSON();
-our $JSON = JSON->new->canonical->utf8;
 
 use namespace::autoclean;
 my @wrapped_classes = qw(
-    domain  namespace      store   view     scope
-    results cached_results scrolled_results result  bulk
+    domain  namespace   store   view    scope
+    results scrolled_results    result
 );
 
 for my $class (@wrapped_classes) {
@@ -26,7 +27,6 @@ for my $class (@wrapped_classes) {
 #===================================
         isa     => Str,
         is      => 'ro',
-        lazy    => 1,
         default => sub { shift->wrap_class($class) }
     );
 }
@@ -62,17 +62,7 @@ has 'es' => (
     isa     => ES,
     is      => 'ro',
     lazy    => 1,
-    builder => '_build_es',
-    coerce  => 1,
-);
-
-#===================================
-has '_unique_index' => (
-#===================================
-    isa     => Str,
-    is      => 'ro',
-    lazy    => 1,
-    builder => '_build_unique_index',
+    builder => '_build_es'
 );
 
 #===================================
@@ -139,18 +129,9 @@ has 'current_scope' => (
 #===================================
 sub BUILD        { shift->doc_class_wrappers }
 sub _build_store { $_[0]->store_class->new( es => $_[0]->es ) }
-sub _build_es    { Search::Elasticsearch->new }
+sub _build_es    { ElasticSearch->new }
 #===================================
 
-#===================================
-sub _build_unique_index {
-#===================================
-    my $self  = shift;
-    my $index = Class::MOP::class_of($self)->unique_index;
-    $self->store->bootstrap_uniques( index => $index );
-    return $index;
-}
-
 #===================================
 sub _build_namespaces {
 #===================================
@@ -345,22 +326,6 @@ sub get_doc_source {
     return $result->{_source};
 }
 
-#===================================
-sub new_partial_doc {
-#===================================
-    my ( $self, %args ) = @_;
-    my $uid = $args{uid}
-        or croak "No UID passed to new_partial_doc()";
-
-    my $source = $args{partial_source}
-        or croak "No (partial_source) passed to new_partial_doc()";
-
-    my $ns = $self->namespace_for_domain( $uid->index );
-
-    my $class = $ns->class_for_type( $uid->type );
-    return $class->meta->new_stub( $uid, $source );
-}
-
 #===================================
 sub doc_exists {
 #===================================
@@ -375,35 +340,14 @@ sub save_doc {
 #===================================
     my ( $self, %args ) = @_;
 
-    my $doc = delete $args{doc};
-    my $uid = $doc->uid;
-
-    croak "Cannot save partial doc type ("
-        . $uid->type
-        . ") id ("
-        . $uid->id . ")"
-        if $uid->is_partial;
-
+    my $doc  = delete $args{doc};
+    my $uid  = $doc->uid;
     my $data = $self->deflate_object($doc);
 
-    my $action
-        = ( $uid->from_store or $uid->id and defined $args{version} )
-        ? 'index_doc'
-        : 'create_doc';
-
-    my $on_unique   = delete $args{on_unique};
+    my $action      = $uid->from_store ? 'index_doc' : 'create_doc';
     my $on_conflict = delete $args{on_conflict};
-
-    my $unique = $self->_update_unique_keys( $doc, $action, $on_unique )
-        or return;
-
-    my $result = eval { $self->store->$action( $uid, $data, %args ) } or do {
-        my $error = $@;
-        $unique->{rollback}->();
-        return $self->_handle_error( $error, $on_conflict, $doc );
-    };
-
-    $unique->{commit}->();
+    my $result      = eval { $self->store->$action( $uid, $data, %args ) }
+        or return $self->_handle_error( $@, $on_conflict, $doc );
 
     $uid->update_from_store($result);
     $doc->_set_source($data);
@@ -415,65 +359,6 @@ sub save_doc {
     return $scope->store_object( $ns->name, $doc );
 }
 
-my $noops = {
-    commit   => sub { },
-    rollback => sub { }
-};
-
-#===================================
-sub _update_unique_keys {
-#===================================
-    my ( $self, $doc, $action, $on_unique ) = @_;
-    my $meta    = Class::MOP::class_of($doc);
-    my $uniques = $meta->unique_keys
-        or return $noops;
-
-    my $from_store = $doc->uid->from_store;
-
-    croak "Cannot overwrite a new doc of class ("
-        . $doc->original_class
-        . ") because it has unique keys"
-        if $action eq 'index_doc' and not $from_store;
-
-    my ( %old, %new );
-    for my $key ( keys %$uniques ) {
-        my $unique_key = $uniques->{$key};
-        my $new        = $doc->$key;
-        no warnings 'uninitialized';
-
-        if ($from_store) {
-            my $old = $doc->_source->{$key};
-            next if $old eq $new;
-            $old{$unique_key} = $old if length $old;
-        }
-
-        $new{$unique_key} = $new if length $new;
-    }
-
-    my $uniq  = $self->_unique_index;
-    my $store = $self->store;
-
-    if ( my %failed
-        = $store->create_unique_keys( index => $uniq, keys => \%new ) )
-    {
-        if ($on_unique) {
-            $on_unique->( $doc, \%failed );
-            return;
-        }
-        croak "Unique keys already exist: "
-            . join( ', ', map { $_ . '/' . $failed{$_} } sort keys %failed );
-
-    }
-    return {
-        commit => sub {
-            $store->delete_unique_keys( index => $uniq, keys => \%old );
-        },
-        rollback => sub {
-            $store->delete_unique_keys( index => $uniq, keys => \%new );
-        },
-    };
-}
-
 #===================================
 sub _handle_error {
 #===================================
@@ -482,22 +367,18 @@ sub _handle_error {
 
     die $error
         unless $on_conflict
-        and $error->is('Conflict');
+            and $error =~ /ElasticSearch::Error::Conflict/;
 
-    my $new;
-    if ( my $current_version = $error->{vars}{current_version} ) {
-        my $uid = Elastic::Model::UID->new(
-            %{ $original->uid->read_params },
-            version    => $current_version,
-            from_store => 1
-        );
-        $new = $self->get_doc( uid => $uid );
+    my $current_version = $error->{-vars}{current_version}
+        or die "Missing current_version from ElasticSearch::Error::Conflict";
 
-    }
-    else {
-        $new = $self->get_doc( uid => $original->uid->clone );
-    }
+    my $uid = Elastic::Model::UID->new(
+        %{ $original->uid->read_params },
+        version    => $current_version,
+        from_store => 1
+    );
 
+    my $new = $self->get_doc( uid => $uid );
     $on_conflict->( $original, $new );
 
     return;
@@ -510,10 +391,8 @@ sub delete_doc {
     my $uid = delete $args{uid}
         or croak "No UID passed to delete_doc()";
 
-    my $unique = $self->_delete_unique_keys($uid);
     my $result = $self->store->delete_doc( $uid, %args )
         or return;
-    $unique->{commit}->();
 
     $uid->update_from_store($result);
 
@@ -524,39 +403,6 @@ sub delete_doc {
     return $uid;
 }
 
-#===================================
-sub _delete_unique_keys {
-#===================================
-    my ( $self, $uid ) = @_;
-
-    my $doc = $self->get_doc( uid => $uid, ignore => 404 )
-        or return $noops;
-
-    my $meta = Class::MOP::class_of($doc);
-    my $uniques = $meta->unique_keys or return $noops;
-
-    my %old;
-    for my $key ( keys %$uniques ) {
-        no warnings 'uninitialized';
-        my $old = $doc->_source->{$key};
-        $old{ $uniques->{$key} } = $old if length $old;
-    }
-    my $uniq  = $self->_unique_index;
-    my $store = $self->store;
-    return {
-        commit => sub {
-            $store->delete_unique_keys(
-                index => $uniq,
-                keys  => \%old
-            );
-        },
-    };
-}
-
-#===================================
-sub bulk { shift->bulk_class->new(@_) }
-#===================================
-
 #===================================
 sub search { shift->store->search(@_) }
 #===================================
@@ -625,19 +471,16 @@ sub map_class {
         _timestamp        => { enabled => 1, path => 'timestamp' },
         numeric_detection => 1,
     );
-    delete $mapping{type};
+
+    $mapping{_source}{compress} = 1;
     return \%mapping;
 }
 
-#===================================
-sub json {$JSON}
-#===================================
-
 1;
 
-=pod
 
-=encoding UTF-8
+
+=pod
 
 =head1 NAME
 
@@ -645,13 +488,13 @@ Elastic::Model::Role::Model - The role applied to your Model
 
 =head1 VERSION
 
-version 0.29_2
+version 0.01
 
 =head1 SYNOPSIS
 
     use MyApp;
 
-    my $es         = Search::Elasticsearch::Compat->new( servers => 'es.domain.com:9200' );
+    my $es         = ElasticSearch->new( servers => 'es.domain.com:9200' );
     my $model      = MyApp->new( es => $es );
 
     my $namespace  = $model->namespace('myapp');
@@ -663,7 +506,7 @@ version 0.29_2
 =head1 DESCRIPTION
 
 A "Model" is the Boss Object, which ties an instance of your application to
-a particular Elasticsearch cluster. You can have multiple instances of your
+a particular ElasticSearch cluster. You can have multiple instances of your
 Model class which connect to different clusters.
 
 C<Elastic::Model::Role::Model> is applied to your Model class when you
@@ -678,12 +521,12 @@ See L<Elastic::Model> for more about how to setup your Model class.
 =head2 new()
 
 Usually, the only parameter that you need to pass to C<new()> is C<es>,
-which contains your L<Search::Elasticsearch::Compat> connection.
+which contains your L<ElasticSearch> connection.
 
-    $es    = Search::Elasticsearch::Compat->new( servers => 'es1.domain.com:9200' );
+    $es    = ElasticSearch->new( servers => 'es1.domain.com:9200' );
     $model = MyApp->new( es => $es );
 
-If the C<es> parameter is omitted, then it will default to a L<Search::Elasticsearch::Compat>
+If the C<es> parameter is omitted, then it will default to an L<ElasticSearch>
 connection to C<localhost:9200>.
 
     $model = MyApp->new();   # localhost:9200
@@ -751,7 +594,7 @@ Normally, you want to use L<Elastic::Model::Domain/"get()"> rather than this
 method.
 
     $doc = $model->get_doc(uid => $uid);
-    $doc = $model->get_doc(uid => $uid, ignore => 404, ...);
+    $doc = $model->get_doc(uid => $uid, ignore_missing => 1, ...);
 
 C<get_doc()> tries to retrieve the object corresponding to the
 L<$uid|Elastic::Model::UID>, first from the L</current_scope()> (if there is one)
@@ -769,10 +612,10 @@ Any other args are passed on to L<Elastic::Model::Store/get_doc()>.
 =head3 get_doc_source()
 
     $doc = $model->get_doc_source(uid => $uid);
-    $doc = $model->get_doc_source(uid => $uid, ignore => 404, ...);
+    $doc = $model->get_doc_source(uid => $uid, ignore_missing => 1, ...);
 
 Calls L<Elastic::Model::Store/"get_doc()"> and returns the raw source hashref
-as stored in Elasticsearch for the doc with the corresponding
+as stored in ElasticSearch for the doc with the corresponding
 L<$uid|Elastic::Model::UID>. Throws an error if it doesn't exist.
 
 Any other args are passed on to L<Elastic::Model::Store/get_doc()>.
@@ -791,9 +634,9 @@ method.
 
     $doc = $model->save_doc(doc => $doc, %args);
 
-Saves C<$doc> to Elasticsearch by calling
+Saves C<$doc> to ElasticSearch by calling
 L<Elastic::Model::Store/"index_doc()"> (if the C<$doc> was originally loaded
-from Elasticsearch), or L<Elastic::Model::Store/"create_doc()">, which
+from ElasticSearch), or L<Elastic::Model::Store/"create_doc()">, which
 will throw an error if a doc with the same C<index|type|id> already
 exists.
 
@@ -802,12 +645,11 @@ L<create_doc()|Elastic::Model::Store/"create_doc()">.
 
 If there is a L</current_scope()> then the object is also stored there.
 
-Also see the L<Elastic::Model::Role::Doc/on_conflict> and
-L<Elastic::Model::Role::Doc/on_unique> parameters.
+Also see the L<Elastic::Model::Role::Doc/on_conflict> parameter.
 
 =head3 delete_doc()
 
-    $uid = $model->delete_doc(uid => $uid, ignore => 404, ...)
+    $uid = $model->delete_doc(uid => $uid, ignore_missing => 1, ...)
 
 Calls L<Elastic::Model::Store/delete_doc()> and returns the updated
 L<Elastic::Model::UID> object. Throws an error if it doesn't exist.
@@ -823,33 +665,6 @@ method.
 
 Passes C<%args> through to L<Elastic::Model::Store/"search()">
 
-=head3 new_partial_doc()
-
-    part_doc = $model->new_partial_doc(
-        uid            => $uid,
-        partial_source => \%source
-    );
-
-Creates an instance of a partial doc (ie an object which contains only some of
-the values stored in Elasticsearch). These partial docs are useful when
-your objects are large, and you need to display search results which
-require only a few attributes, instead of the whole object.
-
-Attempting to save a partial doc will cause an error to be thrown.
-
-You shouldn't need to call this method yourself.
-
-=head3 bulk()
-
-Returns a new instance of L<Elastic::Model::Bulk> for fast indexing
-of multiple docs in batches.
-
-    $bulk = $model->bulk(
-        size        => 1000,
-        on_conflict => sub {....},
-        on_error    => sub {....}
-    );
-
 =head2 Miscellaneous
 
 =head3 namespaces
@@ -871,21 +686,14 @@ C<$model>, it will update the known domain list from the namespace objects.
 
     @indices = $model->all_live_indices();
 
-Queries Elasticsearch to find all existing indices related to all namespaces
+Queries ElasticSearch to find all existing indices related to all namespaces
 known to the model.
 
 =head3 es
 
     $es = $model->es
 
-Returns the L<Search::Elasticsearch::Compat> instance that was passed to L</"new()">.
-
-=head3 es_unique
-
-    $uniq = $model->es_unique
-
-Returns the L<ElasticSearchX::UniqueKey> instance pointing to the index
-specified with L<has_unique_index|Elastic::Model/Custom unique key index>.
+Returns the L<ElasticSearch> instance that was passed to L</"new()">.
 
 =head3 store
 
@@ -902,7 +710,7 @@ Returns the L<Elastic::Model::Store> instance.
 Elastic::Model uses L<Elastic::Model::TypeMap::Default> (after
 L<wrapping|/wrap_class()> it) to figure out how
 to deflate and inflate your objects, and how to configure (map) them in
-Elasticsearch.
+ElasticSearch.
 
 You can specify your own type-map class in your model configuration with
 L<has_typemap|Elastic::Model/Custom TypeMap>. See
@@ -958,7 +766,7 @@ L</"inflator_for_class()">.
     $mapping = $model->map_class($class);
 
 Returns the type mapping / schema for a class which does
-L<Elastic::Model::Role::Doc>, suitable for passing to Elasticsearch.
+L<Elastic::Model::Role::Doc>, suitable for passing to ElasticSearch.
 
 =head2 Scoping
 
@@ -1000,7 +808,7 @@ Clears the L</"current_scope()">
 
 =head2 Core classes
 
-The following core classes are used internally by Elasticsearch, after
+The following core classes are used internally by ElasticSearch, after
 being wrapped by L</wrap_class()>, which pins the new anonymous class
 to the current C<$model> instance. An instance of the wrapped class
 can be created with, eg:
@@ -1037,10 +845,6 @@ C<results_class> C<-------------> L<Elastic::Model::Results>
 
 =item *
 
-C<cached_results_class> C<------> L<Elastic::Model::Results::Cached>
-
-=item *
-
 C<scrolled_results_class> C<----> L<Elastic::Model::Results::Scrolled>
 
 =item *
@@ -1091,13 +895,14 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Clinton Gormley.
+This software is copyright (c) 2012 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
 __END__
 
 # ABSTRACT: The role applied to your Model
