@@ -1,11 +1,14 @@
 package Elastic::Model::Role::Results;
-$Elastic::Model::Role::Results::VERSION = '0.29_2'; # TRIAL
+{
+  $Elastic::Model::Role::Results::VERSION = '0.01'; # TRIAL
+}
+
 use Carp;
 use Moose::Role;
 
 with 'Elastic::Model::Role::Iterator';
 
-use MooseX::Types::Moose qw(HashRef Int Num CodeRef Bool);
+use MooseX::Types::Moose qw(:all);
 use namespace::autoclean;
 
 #===================================
@@ -42,15 +45,6 @@ has 'facets' => (
     handles => { facet => 'get' }
 );
 
-#===================================
-has 'is_partial' => (
-#===================================
-    isa     => Bool,
-    is      => 'ro',
-    lazy    => 1,
-    builder => '_build_is_partial',
-);
-
 #===================================
 has '_as_result' => (
 #===================================
@@ -87,47 +81,14 @@ has '_as_objects' => (
     builder => '_as_objects_builder'
 );
 
-#===================================
-has '_as_partial' => (
-#===================================
-    isa     => CodeRef,
-    is      => 'ro',
-    lazy    => 1,
-    builder => '_as_partial_builder'
-);
-
-#===================================
-has '_as_partials' => (
-#===================================
-    isa     => CodeRef,
-    is      => 'ro',
-    lazy    => 1,
-    builder => '_as_partials_builder'
-);
-
 no Moose;
 
-#===================================
-sub _build_is_partial {
-#===================================
-    my $self   = shift;
-    my $source = $self->search->{_source};
-    return !!( !$source || ref $source );
-}
-
 #===================================
 sub _as_result_builder {
 #===================================
     my $self         = shift;
     my $result_class = $self->model->result_class;
-    my $is_partial   = $self->is_partial;
-    sub {
-        $_[0]
-            && $result_class->new(
-            result     => $_[0],
-            is_partial => $is_partial
-            );
-        }
+    sub { $_[0] && $result_class->new( result => $_[0] ) }
 }
 
 #===================================
@@ -135,77 +96,36 @@ sub _as_results_builder {
 #===================================
     my $self         = shift;
     my $result_class = $self->model->result_class;
-    my $is_partial   = $self->is_partial;
     sub {
-        map { $result_class->new( result => $_, is_partial => $is_partial ) }
-            @_;
+        map { $result_class->new( result => $_ ) } @_;
     };
 }
 
 #===================================
 sub _as_object_builder {
-#===================================
-    my $self       = shift;
-    my $model      = $self->model;
-    my $is_partial = $self->is_partial;
-    sub {
-        my $raw = shift or return;
-        $raw->{_object} ||= do {
-            my $uid = Elastic::Model::UID->new_from_store($raw);
-            my $source = $is_partial ? undef : $raw->{_source};
-            $model->get_doc( uid => $uid, source => $source );
-        };
-    };
-}
-
-#===================================
-sub _as_objects_builder {
-#===================================
-    my $self       = shift;
-    my $m          = $self->model;
-    my $is_partial = $self->is_partial;
-    sub {
-        map {
-            $_->{_object} ||= do {
-                my $uid = Elastic::Model::UID->new_from_store($_);
-                my $source = $is_partial ? undef : $_->{_source};
-                $m->get_doc( uid => $uid, source => $source );
-            };
-        } @_;
-    };
-}
-
-#===================================
-sub _as_partial_builder {
 #===================================
     my $self  = shift;
     my $model = $self->model;
     sub {
         my $raw = shift or return;
-        $raw->{_partial} ||= do {
-            my $uid = Elastic::Model::UID->new_partial($raw);
-            $model->new_partial_doc(
-                uid            => $uid,
-                partial_source => $raw->{_source}
-            );
+        $raw->{_object} ||= do {
+            my $uid = Elastic::Model::UID->new_from_store($raw);
+            $model->get_doc( uid => $uid, source => $raw->{_source} );
             }
 
     };
 }
 
 #===================================
-sub _as_partials_builder {
+sub _as_objects_builder {
 #===================================
     my $self = shift;
     my $m    = $self->model;
     sub {
         map {
-            $_->{_partial} ||= do {
-                my $uid = Elastic::Model::UID->new_partial($_);
-                $m->new_partial_doc(
-                    uid            => $uid,
-                    partial_source => $_->{_source}
-                );
+            $_->{_object} ||= do {
+                my $uid = Elastic::Model::UID->new_from_store($_);
+                $m->get_doc( uid => $uid, source => $_->{_source} );
                 }
         } @_;
     };
@@ -229,15 +149,6 @@ sub as_objects {
     $self;
 }
 
-#===================================
-sub as_partials {
-#===================================
-    my $self = shift;
-    $self->wrapper( $self->_as_partial );
-    $self->multi_wrapper( $self->_as_partials );
-    $self;
-}
-
 #===================================
 sub first_result     { $_[0]->_as_result->( $_[0]->first_element ) }
 sub last_result      { $_[0]->_as_result->( $_[0]->last_element ) }
@@ -276,30 +187,11 @@ sub slice_objects {
     $self->_as_objects->( $self->slice_elements(@_) );
 }
 
-#===================================
-sub first_partial     { $_[0]->_as_partial->( $_[0]->first_element ) }
-sub last_partial      { $_[0]->_as_partial->( $_[0]->last_element ) }
-sub next_partial      { $_[0]->_as_partial->( $_[0]->next_element ) }
-sub prev_partial      { $_[0]->_as_partial->( $_[0]->prev_element ) }
-sub current_partial   { $_[0]->_as_partial->( $_[0]->current_element ) }
-sub peek_next_partial { $_[0]->_as_partial->( $_[0]->peek_next_element ) }
-sub peek_prev_partial { $_[0]->_as_partial->( $_[0]->peek_prev_element ) }
-sub shift_partial     { $_[0]->_as_partial->( $_[0]->shift_element ) }
-sub all_partials      { $_[0]->_as_partials->( $_[0]->all_elements ) }
-#===================================
-
-#===================================
-sub slice_partials {
-#===================================
-    my $self = shift;
-    $self->_as_partials->( $self->slice_elements(@_) );
-}
-
 1;
 
-=pod
 
-=encoding UTF-8
+
+=pod
 
 =head1 NAME
 
@@ -307,14 +199,14 @@ Elastic::Model::Role::Results - An iterator role for search results
 
 =head1 VERSION
 
-version 0.29_2
+version 0.01
 
 =head1 DESCRIPTION
 
 L<Elastic::Model::Role::Results> adds a number of methods and attributes
 to those provided by L<Elastic::Model::Role::Iterator> to better handle
-result sets from Elasticsearch.  It is used by L<Elastic::Model::Results>,
-L<Elastic::Model::Results::Cached> and by L<Elastic::Model::Results::Scrolled>.
+result sets from ElasticSearch.  It is used by L<Elastic::Model::Results>
+and by L<Elastic::Model::Results::Scrolled>.
 
 See those modules for more complete documentation. This module just
 documents the attributes and methods added in L<Elastic::Model::Role::Results>
@@ -331,15 +223,15 @@ The number of L</elements> in the C<$results> object;
 
     $total_matching = $results->total
 
-The total number of matching docs found by Elasticsearch.  This is
+The total number of matching docs found by ElasticSearch.  This is
 distinct from the L</size> which contains the number of results RETURNED
-by Elasticsearch.
+by ElasticSearch.
 
 =head2 max_score
 
     $max_score = $results->max_score
 
-The highest score (relevance) found by Elasticsearch. B<Note:> if you
+The highest score (relevance) found by ElasticSearch. B<Note:> if you
 are sorting by a field other than C<_score> then you will need
 to set L<Elastic::Model::View/track_scores> to true to retrieve the
 L</max_score>.
@@ -384,14 +276,6 @@ Sets the "short" accessors (eg L<Elastic::Model::Role::Iterator/next> or
 L<Elastic::Model::Role::Iterator/prev>) to return the object itself,
 eg C<MyApp::User>
 
-=head2 as_partials()
-
-    $results->as_partials()
-
-Sets the "short" accessors (eg L<Elastic::Model::Role::Iterator/next> or
-L<Elastic::Model::Role::Iterator/prev>) to return partial objects
-as specified by L<Elastic::Model::View/"include_paths / exclude_paths">.
-
 =head1 RESULT ACCESSORS
 
 Each of the methods listed below takes the result of the related
@@ -423,7 +307,7 @@ in an L<Elastic::Model::Result> object. For instance:
 =head1 OBJECT ACCESSORS
 
 Each of the methods listed below takes the result of the related
-C<_element> accessor in L<Elastic::Model::Role::Iterator> and inflates the
+C<_element> accessor in L<Elastic::Model::Role::Iterator> and inflate the
 related object (eg a C<MyApp::User> object). For instance:
 
     $object = $results->next_object;
@@ -448,48 +332,20 @@ related object (eg a C<MyApp::User> object). For instance:
 
 =head2 slice_objects
 
-=head1 PARTIAL OBJECT ACCESSORS
-
-Each of the methods listed below takes the result of the related
-C<_element> accessor in L<Elastic::Model::Role::Iterator> and inflates the
-related partial object as specified by
-L<Elastic::Model::View/"include_paths / exclude_paths">. For instance:
-
-    $object = $results->next_partial;
-
-=head2 first_partial
-
-=head2 last_partial
-
-=head2 next_partial
-
-=head2 prev_partial
-
-=head2 current_partial
-
-=head2 peek_next_partial
-
-=head2 peek_prev_partial
-
-=head2 shift_partial
-
-=head2 all_partials
-
-=head2 slice_partials
-
 =head1 AUTHOR
 
 Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Clinton Gormley.
+This software is copyright (c) 2012 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
 __END__
 
 # ABSTRACT: An iterator role for search results
