@@ -1,10 +1,12 @@
 package Elastic::Model::Scope;
-$Elastic::Model::Scope::VERSION = '0.29_2'; # TRIAL
+{
+  $Elastic::Model::Scope::VERSION = '0.01'; # TRIAL
+}
+
 use Moose;
 use namespace::autoclean;
-use MooseX::Types::Moose qw(HashRef);
+use MooseX::Types::Moose qw(:all);
 use Scalar::Util qw(refaddr);
-use Devel::GlobalDestruction;
 
 #===================================
 has '_objects' => (
@@ -104,15 +106,14 @@ sub delete_object {
 sub DEMOLISH {
 #===================================
     my $self = shift;
-    return if in_global_destruction;
     $self->model->detach_scope($self);
 }
 
 1;
 
-=pod
 
-=encoding UTF-8
+
+=pod
 
 =head1 NAME
 
@@ -120,7 +121,7 @@ Elastic::Model::Scope - Keeps objects alive and connected
 
 =head1 VERSION
 
-version 0.29_2
+version 0.01
 
 =head1 DESCRIPTION
 
@@ -162,7 +163,7 @@ The logic used in scopes is best explained by the examples below:
     $obj = $scope->get_object($domain_name, $uid);
 
 When calling L<Elastic::Model::Domain/"get()"> or L<Elastic::Model::Role::Model/"get_doc()">
-to retrieve an object from Elasticsearch, we first check to see if we can
+to retrieve an object from ElasticSearch, we first check to see if we can
 return the object from our in-memory cache by calling L</get_object()>:
 
 =head3 Getting an object that exists in the current scope
@@ -191,7 +192,7 @@ we return the SAME object.
 If an object with the same C<domain_name/type/id> exists in the PARENT scope
 (and its version is as least as high as the requested version, if any) then
 we return a CLONE of the object. (Note: we clone the original object as it was
-when loaded from Elasticsearch. Any unsaved changes are ignored.)
+when loaded from ElasticSearch. Any unsaved changes are ignored.)
 
     $scope_1 = $model->new_scope;
     $one     = $domain->get( user => 123 );
@@ -210,7 +211,7 @@ when loaded from Elasticsearch. Any unsaved changes are ignored.)
     print refaddr($one) == refaddr($two) ? 'TRUE' : 'FALSE';
     # FALSE
 
-Otherwise the calling method will fetch the object from Elasticsearch itself,
+Otherwise the calling method will fetch the object from ElasticSearch itself,
 and store it in the current scope.
 
 =head3 Getting an object that has been deleted
@@ -328,13 +329,14 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Clinton Gormley.
+This software is copyright (c) 2012 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
 __END__
 
 # ABSTRACT: Keeps objects alive and connected
