@@ -1,8 +1,11 @@
 package Elastic::Model::Trait::Exclude;
-$Elastic::Model::Trait::Exclude::VERSION = '0.29_2'; # TRIAL
+{
+  $Elastic::Model::Trait::Exclude::VERSION = '0.01'; # TRIAL
+}
+
 use Moose::Role;
 use Moose::Exporter;
-use MooseX::Types::Moose qw(Bool);
+use MooseX::Types::Moose qw(:all);
 use namespace::autoclean;
 
 Moose::Exporter->setup_import_methods(
@@ -15,9 +18,9 @@ has 'exclude' => ( isa => Bool, is => 'ro', default => 1 );
 
 1;
 
-=pod
 
-=encoding UTF-8
+
+=pod
 
 =head1 NAME
 
@@ -25,12 +28,12 @@ Elastic::Model::Trait::Exclude - An internal use trait
 
 =head1 VERSION
 
-version 0.29_2
+version 0.01
 
 =head1 DESCRIPTION
 
 This trait is used by Elastic::Model doc attributes which shouldn't be
-stored in Elasticsearch. It implements just the
+stored in ElasticSearch. It implements just the
 L<Elastic::Model::Trait::Field/"exclude"> keyword.
 
 =head1 AUTHOR
@@ -39,13 +42,14 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Clinton Gormley.
+This software is copyright (c) 2012 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
 __END__
 
 # ABSTRACT: An internal use trait
