@@ -1,8 +1,9 @@
 package Elastic::Model::Trait::Field;
-$Elastic::Model::Trait::Field::VERSION = '0.29_2'; # TRIAL
-use Moose::Role;
-Moose::Util::meta_attribute_alias('ElasticField');
+{
+  $Elastic::Model::Trait::Field::VERSION = '0.01'; # TRIAL
+}
 
+use Moose::Role;
 use MooseX::Types::Moose qw(
     Str HashRef ArrayRef Bool Num Int CodeRef
 );
@@ -14,11 +15,42 @@ use Carp;
 
 use namespace::autoclean;
 
+#===================================
+around [
+    '_inline_instance_get',   '_inline_instance_set',
+    '_inline_instance_clear', '_inline_instance_has'
+    ]
+#===================================
+    => sub {
+    my ( $orig, $attr, $instance, @args ) = @_;
+    my $inline = $attr->$orig( $instance, @args );
+    unless ( $attr->exclude ) {
+        $inline = <<"INLINE"
+    do {
+        $instance->_can_inflate && $instance->_inflate_doc;
+        $inline
+    }
+INLINE
+    }
+    return $inline;
+    };
+
+#===================================
+around [ 'get_value', 'set_value', 'clear_value', 'has_value' ]
+#===================================
+    => sub {
+    my ( $orig, $attr, $instance, @args ) = @_;
+    unless ( $attr->exclude ) {
+        $instance->_can_inflate && $instance->_inflate_doc;
+    }
+    return $attr->$orig( $instance, @args );
+    };
+
 #===================================
 has 'type' => (
 #===================================
     isa       => FieldType,
-    is        => 'rw',
+    is        => 'ro',
     predicate => 'has_type'
 );
 
@@ -26,35 +58,35 @@ has 'type' => (
 has 'mapping' => (
 #===================================
     isa => HashRef [Str],
-    is => 'rw'
+    is => 'ro'
 );
 
 #===================================
 has 'exclude' => (
 #===================================
     isa => Bool,
-    is  => 'rw'
+    is  => 'ro'
 );
 
 #===================================
 has 'include_in_all' => (
 #===================================
     isa => Bool,
-    is  => 'rw'
+    is  => 'ro'
 );
 
 #===================================
 has 'index' => (
 #===================================
     isa => IndexMapping,
-    is  => 'rw'
+    is  => 'ro'
 );
 
 #===================================
 has 'store' => (
 #===================================
     isa    => StoreMapping,
-    is     => 'rw',
+    is     => 'ro',
     coerce => 1
 );
 
@@ -62,35 +94,28 @@ has 'store' => (
 has 'multi' => (
 #===================================
     isa => MultiFields,
-    is  => 'rw'
+    is  => 'ro'
 );
 
 #===================================
 has 'index_name' => (
 #===================================
     isa => Str,
-    is  => 'rw'
+    is  => 'ro'
 );
 
 #===================================
 has 'boost' => (
 #===================================
     isa => Num,
-    is  => 'rw'
+    is  => 'ro'
 );
 
 #===================================
 has 'null_value' => (
 #===================================
     isa => Str,
-    is  => 'rw'
-);
-
-#===================================
-has 'unique_key' => (
-#===================================
-    isa => Str,
-    is  => 'rw'
+    is  => 'ro'
 );
 
 # strings
@@ -99,35 +124,49 @@ has 'unique_key' => (
 has 'analyzer' => (
 #===================================
     isa => Str,
-    is  => 'rw'
+    is  => 'ro'
 );
 
 #===================================
 has 'index_analyzer' => (
 #===================================
     isa => Str,
-    is  => 'rw'
+    is  => 'ro'
 );
 
 #===================================
 has 'search_analyzer' => (
 #===================================
     isa => Str,
-    is  => 'rw'
+    is  => 'ro'
 );
 
 #===================================
 has 'search_quote_analyzer' => (
 #===================================
     isa => Str,
-    is  => 'rw'
+    is  => 'ro'
+);
+
+#===================================
+has 'omit_norms' => (
+#===================================
+    isa => Bool,
+    is  => 'ro'
+);
+
+#===================================
+has 'omit_term_freq_and_positions' => (
+#===================================
+    isa => Bool,
+    is  => 'ro'
 );
 
 #===================================
 has 'term_vector' => (
 #===================================
     isa => TermVectorMapping,
-    is  => 'rw'
+    is  => 'ro'
 );
 
 # dates
@@ -136,14 +175,14 @@ has 'term_vector' => (
 has 'format' => (
 #===================================
     isa => Str,
-    is  => 'rw'
+    is  => 'ro'
 );
 
 #===================================
 has 'precision_step' => (
 #===================================
     isa => Int,
-    is  => 'rw'
+    is  => 'ro'
 );
 
 # geo-point
@@ -152,21 +191,21 @@ has 'precision_step' => (
 has 'geohash' => (
 #===================================
     isa => Bool,
-    is  => 'rw'
+    is  => 'ro'
 );
 
 #===================================
 has 'lat_lon' => (
 #===================================
     isa => Bool,
-    is  => 'rw'
+    is  => 'ro'
 );
 
 #===================================
 has 'geohash_precision' => (
 #===================================
     isa => Int,
-    is  => 'rw'
+    is  => 'ro'
 );
 
 # object
@@ -175,7 +214,7 @@ has 'geohash_precision' => (
 has 'enabled' => (
 #===================================
     isa       => Bool,
-    is        => 'rw',
+    is        => 'ro',
     predicate => 'has_enabled'
 );
 
@@ -183,14 +222,14 @@ has 'enabled' => (
 has 'dynamic' => (
 #===================================
     isa => DynamicMapping,
-    is  => 'rw'
+    is  => 'ro'
 );
 
 #===================================
 has 'path' => (
 #===================================
     isa => PathMapping,
-    is  => 'rw'
+    is  => 'ro'
 );
 
 # nested
@@ -199,14 +238,14 @@ has 'path' => (
 has 'include_in_parent' => (
 #===================================
     isa => Bool,
-    is  => 'rw'
+    is  => 'ro'
 );
 
 #===================================
 has 'include_in_root' => (
 #===================================
     isa => Bool,
-    is  => 'rw'
+    is  => 'ro'
 );
 
 # deflation
@@ -215,14 +254,14 @@ has 'include_in_root' => (
 has 'deflator' => (
 #===================================
     isa => CodeRef,
-    is  => 'rw'
+    is  => 'ro'
 );
 
 #===================================
 has 'inflator' => (
 #===================================
     isa => CodeRef,
-    is  => 'rw'
+    is  => 'ro'
 );
 
 # esdocs
@@ -231,36 +270,66 @@ has 'inflator' => (
 has 'include_attrs' => (
 #===================================
     isa => ArrayRef [Str],
-    is => 'rw'
+    is => 'ro'
 );
 
 #===================================
 has 'exclude_attrs' => (
 #===================================
     isa => ArrayRef [Str],
-    is => 'rw'
+    is => 'ro'
 );
 
+#===================================
+before '_process_options' => sub {
+#===================================
+    my ( $class, $name, $opts ) = @_;
+    if ( my $orig = $opts->{trigger} ) {
+        ( 'CODE' eq ref $orig )
+            || $class->throw_error(
+            "Trigger must be a CODE ref on attribute ($name)",
+            data => $opts->{trigger} );
+        $opts->{trigger} = sub {
+            my $self = shift;
+            no warnings 'uninitialized';
+            unless ( @_ == 2 && $_[1] eq $_[0] ) {
+                $self->has_changed( $name, $_[1] );
+            }
+            $self->$orig(@_);
+        };
+    }
+    else {
+
+        $opts->{trigger} = sub {
+            my $self = shift;
+            no warnings 'uninitialized';
+            unless ( @_ == 2 && $_[1] eq $_[0] ) {
+                $self->has_changed( $name, $_[1] );
+            }
+        };
+    }
+};
+
 1;
 
-=pod
 
-=encoding UTF-8
+
+=pod
 
 =head1 NAME
 
-Elastic::Model::Trait::Field - Add Elasticsearch specific keywords to your attribute definitions.
+Elastic::Model::Trait::Field - Add ElasticSearch specific keywords to your attribute definitions.
 
 =head1 VERSION
 
-version 0.29_2
+version 0.01
 
 =head1 DESCRIPTION
 
 L<Elastic::Model::Trait::Field> is automatically applied to all of your
 attributes when you include C<use Elastic::Doc;> at the top of your doc
 classes. This trait adds keywords to allow you to configure how each attribute
-is indexed in Elasticsearch.
+is indexed in ElasticSearch.
 
 It also wraps all attribute accessors to ensure that Elastic::Doc objects
 are properly inflated before any attribute is accessed.
@@ -298,6 +367,10 @@ keywords.
 
 =head2 L<search_quote_analyzer|Elastic::Manual::Attributes/search_quote_analyzer>
 
+=head2 L<omit_norms|Elastic::Manual::Attributes/omit_norms>
+
+=head2 L<omit_term_freq_and_positions|Elastic::Manual::Attributes/omit_term_freq_and_positions>
+
 =head2 L<term_vector|Elastic::Manual::Attributes/term_vector>
 
 =head2 L<format|Elastic::Manual::Attributes/format>
@@ -334,14 +407,15 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Clinton Gormley.
+This software is copyright (c) 2012 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
 __END__
 
-# ABSTRACT: Add Elasticsearch specific keywords to your attribute definitions.
+# ABSTRACT: Add ElasticSearch specific keywords to your attribute definitions.
 
