@@ -1,11 +1,13 @@
 package Elastic::Model::TypeMap::Base;
-$Elastic::Model::TypeMap::Base::VERSION = '0.29_2'; # TRIAL
+{
+  $Elastic::Model::TypeMap::Base::VERSION = '0.01'; # TRIAL
+}
+
 use strict;
 use warnings;
 
 use Sub::Exporter qw(build_exporter);
 use Class::MOP();
-use Class::Load();
 use List::MoreUtils qw(uniq);
 use Moose::Util qw(does_role);
 use Scalar::Util qw(blessed);
@@ -28,8 +30,8 @@ sub import {
         unshift @{ $callee . '::ISA' }, __PACKAGE__;
     }
 
-    build_exporter(
-        {   into    => $callee,
+    build_exporter( {
+            into    => $callee,
             exports => [
                 qw(deflate_via inflate_via map_via),
                 has_type => sub {
@@ -41,23 +43,13 @@ sub import {
 
     for (@args) {
         next if /^[:-]/;
-        Class::Load::load_class($_);
+        Class::MOP::load_class($_);
         $callee->import_types( $_->typemap );
     }
 }
 
 #===================================
 sub find_deflator {
-#===================================
-    my ( $map, $attr ) = @_;
-    my $deflator = $map->find_raw_deflator($attr);
-    return $deflator if ref $deflator;
-    Eval::Closure::eval_closure(
-        source => [ 'sub { my $val = $_[0];', $deflator, '}' ] );
-}
-
-#===================================
-sub find_raw_deflator {
 #===================================
     my ( $map, $attr ) = @_;
     $attr->can('deflator') && $attr->deflator
@@ -67,16 +59,6 @@ sub find_raw_deflator {
 
 #===================================
 sub find_inflator {
-#===================================
-    my ( $map, $attr ) = @_;
-    my $inflator = $map->find_raw_inflator($attr);
-    return $inflator if ref $inflator;
-    Eval::Closure::eval_closure(
-        source => [ 'sub { my $val = $_[0];', $inflator, '}' ] );
-}
-
-#===================================
-sub find_raw_inflator {
 #===================================
     my ( $map, $attr ) = @_;
     $attr->can('inflator') && $attr->inflator
@@ -144,53 +126,28 @@ sub class_deflator {
 
     $attrs ||= $map->indexable_attrs($class);
 
-    my %deflators = map { $_ => $map->find_raw_deflator( $attrs->{$_} ) }
+    my %deflators = map { $_ => $map->find_deflator( $attrs->{$_} ) }
         keys %$attrs;
 
-    my @src = ( 'sub {', 'my $self = shift;', 'my (%hash,$attr,$val);',
-        'eval {', );
-
-    my %readers;
-    for my $name ( sort keys %deflators ) {
-        my $attr     = $attrs->{$name};
-        my $deflator = $deflators{$name};
-        if ( ref $deflator ) {
-            $deflator = '$deflators{"' . $name . '"}->($val)';
+    my $has_uid = $class->can('uid');
+    return sub {
+        my $obj = shift;
+        my %hash;
+        for ( keys %deflators ) {
+            my $attr = $attrs->{$_};
+            unless ( $attr->has_value($obj) ) {
+                next unless $attr->has_builder;
+                my $reader = $attr->get_read_method_ref;
+                $obj->$reader;
+            }
+            my $val = $attr->get_raw_value($obj);
+            eval { $hash{$_} = $deflators{$_}->($val); 1 } and next;
+            die "Error deflating attribute ($_) in class "
+                . blessed($obj) . ":\n  "
+                . ( $@ || 'Unknown error' );
         }
-        my $is_lazy = $attr->is_lazy;
-        my $get_raw = $attr->_inline_instance_get('$self');
-        my $exists  = $attr->_inline_instance_has('$self');
-
-        push @src, '$attr="' . $name . '";';
-        if ($is_lazy) {
-            $readers{$name} = $attr->get_read_method_ref;
-            push @src, '$readers{"' . $name . '"}->($self);';
-        }
-        else {
-            push @src, "if ($exists) {";
-        }
-        push @src, '$val = ' . $get_raw . ';',
-            '$hash{"' . $name . '"} = ' . $deflator . ';';
-        push @src, '}' unless $is_lazy;
-    }
-
-    push @src,
-        (
-        '1;} ',
-        'or die "Error deflating attribute ($attr) in class ".',
-        'Scalar::Util::blessed($self).',
-        '":\n ".($@ || "Unknown error");',
-        'return \%hash',
-        '}'
-        );
-
-    Eval::Closure::eval_closure(
-        source      => \@src,
-        environment => {
-            '%deflators' => \%deflators,
-            '%readers'   => \%readers
-        }
-    );
+        return \%hash;
+    };
 }
 
 #===================================
@@ -199,63 +156,37 @@ sub class_inflator {
     my ( $map, $class, $attrs ) = @_;
 
     $attrs ||= $map->indexable_attrs($class);
-    my %inflators = map { $_ => $map->find_raw_inflator( $attrs->{$_} ) }
+    my %inflators = map { $_ => $map->find_inflator( $attrs->{$_} ) }
         keys %$attrs;
 
-    my @src = (
-        'sub {',
-        'my ($self,$hash) = @_;',
-        'my ($attr,$val,$res);',
-        'eval {'
-    );
-    for my $name ( sort keys %inflators ) {
-        my $attr     = $attrs->{$name};
-        my $inflator = $inflators{$name};
-        my $set_raw  = $attr->_inline_instance_set( '$self', '$res' );
-        if ( ref $inflator ) {
-            $inflator = '$inflators{"' . $name . '"}->($val)';
+    return sub {
+        my ( $obj, $hash ) = @_;
+        for ( keys %$hash ) {
+            my $attr = $attrs->{$_} or next;
+            my $val = $inflators{$_}->( $hash->{$_} );
+            $attr->set_raw_value( $obj, $val );
+            $attr->_weaken_value($obj) if $attr->is_weak_ref;
         }
-        push @src,
-            (
-            '$attr = "' . $name . '";',
-            'if (exists $hash->{"' . $name . '"}) {',
-            '$val = $hash->{"' . $name . '"};',
-            '$res = ' . $inflator . ';',
-            $set_raw . ';',
-            $attr->_inline_weaken_value( '$self', '$res' ),
-            '}'
-            );
-    }
-    push @src,
-        (
-        '1}',
-        'or die "Error inflating attribute ($attr) in class ".',
-        'Scalar::Util::blessed($self).',
-        '":\n ".($@ || "Unknown error");',
-        'return $self',
-        '}'
-        );
-
-    Eval::Closure::eval_closure(
-        source      => \@src,
-        environment => { '%inflators' => \%inflators, }
-    );
+        return $obj;
+    };
 }
 
 our %Allowed_Attrs = (
     string => {
-        'index_name'            => 1,
-        'store'                 => 1,
-        'index'                 => 1,
-        'term_vector'           => 1,
-        'boost'                 => 1,
-        'null_value'            => 1,
-        'analyzer'              => 1,
-        'index_analyzer'        => 1,
-        'search_analyzer'       => 1,
-        'search_quote_analyzer' => 1,
-        'include_in_all'        => 1,
-        'multi'                 => 1,
+        'index_name'                   => 1,
+        'store'                        => 1,
+        'index'                        => 1,
+        'term_vector'                  => 1,
+        'boost'                        => 1,
+        'null_value'                   => 1,
+        'omit_norms'                   => 1,
+        'omit_term_freq_and_positions' => 1,
+        'analyzer'                     => 1,
+        'index_analyzer'               => 1,
+        'search_analyzer'              => 1,
+        'search_quote_analyzer'        => 1,
+        'include_in_all'               => 1,
+        'multi'                        => 1,
     },
     integer => {
         'index_name'     => 1,
@@ -419,6 +350,11 @@ sub _fixup_mapping {
     delete $defn->{analyzer}
         if $defn->{index_analyzer} && $defn->{search_analyzer};
 
+    # make 'undef' a false value for boolean fields
+    $defn->{null_value} = 0
+        if $defn->{type} eq 'boolean'
+            and not exists $defn->{null_value};
+
     return $defn;
 }
 
@@ -482,9 +418,9 @@ sub import_types {
 
 1;
 
-=pod
 
-=encoding UTF-8
+
+=pod
 
 =head1 NAME
 
@@ -492,7 +428,7 @@ Elastic::Model::TypeMap::Base - A base class for all TypeMaps
 
 =head1 VERSION
 
-version 0.29_2
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -509,12 +445,6 @@ version 0.29_2
         inflate_via { sub { ... }},
         map_via     { type => 'string' };
 
-    # Inlined in/deflation
-    has_type 'MyCustomType',
-        deflate_via { '$val * 1000'},
-        inflate_via { '$val / 1000'},
-        map_via     { type => 'string' };
-
 =head2 Use your type map by declaring it in your Model
 
     package MyApp;
@@ -532,13 +462,13 @@ version 0.29_2
 
 Moose's L<type constraints|Moose::Util::TypeConstraints> and introspection
 allows Elastic::Model to figure out how to map your data model to the
-Elasticsearch backend with the minimum of effort on your part.
+ElasticSearch backend with the minimum of effort on your part.
 
 What YOU need to do is: B<Be specific about the type constraint for each attribute.>
 
 For instance,  if you have an attribute called C<count>, then specify the
 type constraint C<< isa => 'Int' >>.
-That way, we know how to define the field in Elasticsearch, and how to deflate
+That way, we know how to define the field in ElasticSearch, and how to deflate
 and inflate the value.
 
 Type constraints can inherit their mapping, inflator and deflator from
@@ -561,7 +491,7 @@ existing index.
 =item *
 
 how Elastic::Model will deflate and inflate each attribute when saving or
-retrieving docs stored in Elasticsearch.
+retrieving docs stored in ElasticSearch.
 
 =back
 
@@ -610,16 +540,6 @@ returns a coderef:
         }
     }
 
-Alternatively, the C<deflate_via> and C<inflate_via> coderefs can, when
-executed, return a string of Perl code which can be inlined for more
-efficient flation.  Both the inflator and deflator are passed the value
-that needs to be converted in C<$val>. For instance:
-
-    has_type 'MyDateType',
-        deflate_via { '$val->to_string'            },
-        inflate_via { 'My::Date::Class->new($val)' },
-        map_via     { 'type' => 'date'             };
-
 C<map_via> expects a coderef which returns the mapping for that type as a list,
 not as a hashref:
 
@@ -636,36 +556,19 @@ Here is an example of how to define a type map for DateTime objects:
 
     has_type 'DateTime',
 
-    deflate_via {
-        sub { $_[0]->set_time_zone('UTC')->iso8601 };
-    },
+        deflate_via {
+            sub { $_[0]->set_time_zone('UTC')->iso8601 };
+        },
 
-    inflate_via {
-        sub {
-            my %args;
-            @args{ (qw(year month day hour minute second)) } = split /\D/, shift;
-            DateTime->new(%args);
-        };
-    },
+        inflate_via {
+            sub {
+                my %args;
+                @args{ (qw(year month day hour minute second)) } = split /\D/, shift;
+                DateTime->new(%args);
+            };
+        },
 
-    map_via { type => 'date' };
-
-=head2 An inlined example:
-
-    use DateTime;
-
-    has_type 'DateTime',
-
-    deflate_via { '$val->set_time_zone("UTC")->iso8601' },
-    inflate_via {
-         'do {'
-       . '  my %args;'
-       . '  @args{ (qw(year month day hour minute second)) } = split /\D/, $val;'
-       . '  DateTime->new(%args);'
-       . '}'
-    },
-
-    map_via { type => 'date' };
+        map_via { type => 'date' };
 
 =head1 ATTRIBUTES
 
@@ -710,28 +613,12 @@ and no C<new()>.
     $deflator = $class->find_deflator($attr)
 
 Returns a coderef which knows how to deflate C<$attr>, or throws an exception.
-Any inlined deflators are eval'ed into an anonymous sub.
-
-=head2 find_raw_deflator()
-
-    $deflator = $class->find_deflator($attr)
-
-Returns a coderef which knows how to deflate C<$attr>, or throws an exception.
-Any inlined deflators are returned as strings.
 
 =head2 find_inflator()
 
     $inflator = $class->find_inflator($attr)
 
 Returns a coderef which knows how to inflate C<$attr>, or throws an exception.
-Any inlined inflators are eval'ed into an anonymous sub.
-
-=head2 find_raw_inflator()
-
-    $inflator = $class->find_inflator($attr)
-
-Returns a coderef which knows how to inflate C<$attr>, or throws an exception.
-Any inlined inflators are returned as strings.
 
 =head2 find_mapper()
 
@@ -794,13 +681,14 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Clinton Gormley.
+This software is copyright (c) 2012 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
 __END__
 
 # ABSTRACT: A base class for all TypeMaps
