@@ -1,5 +1,8 @@
 package Elastic::Model::TypeMap::Common;
-$Elastic::Model::TypeMap::Common::VERSION = '0.29_2'; # TRIAL
+{
+  $Elastic::Model::TypeMap::Common::VERSION = '0.01'; # TRIAL
+}
+
 use strict;
 use warnings;
 
@@ -9,10 +12,17 @@ use namespace::autoclean;
 #===================================
 has_type 'DateTime',
 #===================================
-    deflate_via {'$val->set_time_zone("UTC")->iso8601'}, inflate_via {
-    'do { my %args;'
-        . '@args{ (qw(year month day hour minute second)) } = split /\D/, $val;'
-        . 'DateTime->new(%args);' . '}';
+    deflate_via {
+    require DateTime;
+    sub { $_[0]->set_time_zone('UTC')->iso8601 };
+    },
+
+    inflate_via {
+    sub {
+        my %args;
+        @args{ (qw(year month day hour minute second)) } = split /\D/, shift;
+        DateTime->new(%args);
+    };
     },
 
     map_via { type => 'date' };
@@ -20,19 +30,17 @@ has_type 'DateTime',
 
 # ABSTRACT: Type maps for commonly used types
 
+
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Elastic::Model::TypeMap::Common - Type maps for commonly used types
 
 =head1 VERSION
 
-version 0.29_2
+version 0.01
 
 =head1 DESCRIPTION
 
@@ -53,9 +61,10 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Clinton Gormley.
+This software is copyright (c) 2012 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
