@@ -1,5 +1,8 @@
 package Elastic::Model::TypeMap::ES;
-$Elastic::Model::TypeMap::ES::VERSION = '0.29_2'; # TRIAL
+{
+  $Elastic::Model::TypeMap::ES::VERSION = '0.01'; # TRIAL
+}
+
 use strict;
 use warnings;
 
@@ -10,19 +13,29 @@ use namespace::autoclean;
 has_type 'Elastic::Model::Types::UID',
 #===================================
     deflate_via {
-    'do {'
-        . 'die "Cannot deflate UID as it not saved\n"'
-        . 'unless $val->from_store;'
-        . '$val->read_params;' . '}';
+    sub {
+        die "Cannot deflate UID as it not saved\n"
+            unless $_[0]->from_store;
+        $_[0]->read_params;
+        }
     },
 
     inflate_via {
-    'Elastic::Model::UID->new( from_store => 1, %$val  )';
+    sub {
+        Elastic::Model::UID->new( from_store => 1, @{ $_[0] } );
+        }
     },
 
     map_via {
-    my %props = map { $_ => { type => 'string', index => 'not_analyzed', } }
-        qw(index type id routing);
+    my %props = map {
+        $_ => {
+            type                         => 'string',
+            index                        => 'not_analyzed',
+            omit_norms                   => 1,
+            omit_term_freq_and_positions => 1,
+            index_name                   => "uid.${_}",
+            }
+    } qw(index type id routing);
 
     $props{routing}{index} = 'no';
     delete $props{routing}{index_name};
@@ -31,24 +44,22 @@ has_type 'Elastic::Model::Types::UID',
         type       => 'object',
         dynamic    => 'strict',
         properties => \%props,
-        path       => 'full'
+        path       => 'just_name'
     );
 
     };
 
-#===================================
-has_type 'Elastic::Model::Types::Keyword',
-#===================================
-    map_via {
-    type  => 'string',
-    index => 'not_analyzed'
-    };
-
 #===================================
 has_type 'Elastic::Model::Types::GeoPoint',
 #===================================
-    deflate_via {'$val'},
-    inflate_via {'$val'},
+    deflate_via {
+    sub { $_[0] }
+    },
+
+    inflate_via {
+    sub { $_[0] }
+    },
+
     map_via { type => 'geo_point' };
 
 #===================================
@@ -56,11 +67,12 @@ has_type 'Elastic::Model::Types::Binary',
 #===================================
     deflate_via {
     require MIME::Base64;
-    'MIME::Base64::encode_base64( $val )';
+    sub { MIME::Base64::encode_base64( $_[0] ) };
+
     },
 
     inflate_via {
-    'MIME::Base64::decode_base64( $val )';
+    sub { MIME::Base64::decode_base64( $_[0] ) }
     },
 
     map_via { type => 'binary' };
@@ -68,49 +80,39 @@ has_type 'Elastic::Model::Types::Binary',
 #===================================
 has_type 'Elastic::Model::Types::Timestamp',
 #===================================
-    deflate_via {'int( $val * 1000 + 0.5 )'},
-    inflate_via {'sprintf "%.3f", $val / 1000'},
+    deflate_via {
+    sub { int( $_[0] * 1000 + 0.5 ) }
+    },
+
+    inflate_via {
+    sub { sprintf "%.3f", $_[0] / 1000 }
+    },
+
     map_via { type => 'date' };
 
 1;
 
 # ABSTRACT: Type maps for ElasticSearch-specific types
 
+
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Elastic::Model::TypeMap::ES - Type maps for ElasticSearch-specific types
 
 =head1 VERSION
 
-version 0.29_2
+version 0.01
 
 =head1 DESCRIPTION
 
 L<Elastic::Model::TypeMap::ES> provides mapping, inflation and deflation
-for Elasticsearch specific types.
+for ElasticSearch specific types.
 
 =head1 TYPES
 
-=head2 Elastic::Model::Types::Keyword
-
-Attributes of type L<Elastic::Model::Types/Keyword> are in/deflated
-via L<Elastic::Model::TypeMap::Moose/Any> and are mapped as:
-
-    {
-        type                         => 'string',
-        index                        => 'not_analyzed'
-    }
-
-It is a suitable type to use for string attributes which should not
-be analyzed, and will not be used for scoring. Rather they are suitable
-to use as filters.
-
 =head2 Elastic::Model::Types::UID
 
 An L<Elastic::Model::UID> is deflated into a hash ref and reinflated
@@ -119,23 +121,34 @@ via L<Elastic::Model::UID/"new_from_store()">. It is mapped as:
     {
         type        => 'object',
         dynamic     => 'strict',
-        path        => 'path',
+        path        => 'just_name',
         properties  => {
             index   => {
                 type                         => 'string',
-                index                        => 'not_analyzed'
+                index                        => 'not_analyzed',
+                index_name                   => 'uid.index',
+                omit_norms                   => 1,
+                omit_term_freq_and_positions => 1,
             },
             type => {
                 type                         => 'string',
-                index                        => 'not_analyzed'
+                index                        => 'not_analyzed',
+                index_name                   => 'uid.type',
+                omit_norms                   => 1,
+                omit_term_freq_and_positions => 1,
             },
             id   => {
                 type                         => 'string',
-                index                        => 'not_analyzed'
+                index                        => 'not_analyzed',
+                index_name                   => 'uid.id',
+                omit_norms                   => 1,
+                omit_term_freq_and_positions => 1,
             },
             routing   => {
                 type                         => 'string',
-                index                        => 'no'
+                index                        => 'no',
+                omit_norms                   => 1,
+                omit_term_freq_and_positions => 1,
             },
         }
     }
@@ -157,21 +170,16 @@ Attributes of type L<Elastic::Model::Types/"Timestamp"> are deflated
 to epoch milliseconds, and inflated to epoch seconds (with floating-point
 milliseconds). It is mapped as C<< { type => 'date' } >>.
 
-B<Note:> When querying timestamp fields in a View you will need to express the
-comparison values as epoch milliseconds or as an RFC3339 datetime:
-
-    { my_timestamp => { '>' => 1351748867 * 1000      }}
-    { my_timestamp => { '>' => '2012-11-01T00:00:00Z' }}
-
 =head1 AUTHOR
 
 Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Clinton Gormley.
+This software is copyright (c) 2012 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
