@@ -1,5 +1,8 @@
 package Elastic::Model::TypeMap::Moose;
-$Elastic::Model::TypeMap::Moose::VERSION = '0.29_2'; # TRIAL
+{
+  $Elastic::Model::TypeMap::Moose::VERSION = '0.01'; # TRIAL
+}
+
 use strict;
 use warnings;
 
@@ -9,8 +12,8 @@ use namespace::autoclean;
 #===================================
 has_type 'Any',
 #===================================
-    deflate_via {'$val'},
-    inflate_via {'$val'},
+    deflate_via { \&_pass_through },
+    inflate_via { \&_pass_through },
     map_via { type => 'object', enabled => 0 };
 
 #===================================
@@ -41,8 +44,14 @@ has_type 'Int',
 #===================================
 has_type 'ScalarRef',
 #===================================
-    deflate_via {'$$val'},
-    inflate_via {'\$val'},
+    deflate_via {
+    sub { ${ $_[0] } }
+    },
+
+    inflate_via {
+    sub { \$_[0] }
+    },
+
     map_via { _content_handler( 'mapper', @_ ) };
 
 #===================================
@@ -85,22 +94,19 @@ has_type 'HashRef',
 has_type 'Maybe',
 #===================================
     deflate_via { _flate_maybe( 'deflator', @_ ) },
-    inflate_via { _flate_maybe( 'inflator', @_ ) }, map_via {
-    my $tc = $_[0];
-    return ( type => 'boolean' )
-        if $tc->can('type_parameter')
-        and $tc->type_parameter->name eq 'Bool';
-    _content_handler( 'mapper', @_ );
-    };
+    inflate_via { _flate_maybe( 'inflator', @_ ) },
+    map_via { _content_handler( 'mapper', @_ ) };
 
 #===================================
 has_type 'Moose::Meta::TypeConstraint::Enum',
 #===================================
-    deflate_via {'$val'},    #
-    inflate_via {'$val'},
+    deflate_via { \&_pass_through },    #
+    inflate_via { \&_pass_through },
     map_via {
-    type  => 'string',
-    index => 'not_analyzed',
+    type                         => 'string',
+    index                        => 'not_analyzed',
+    omit_norms                   => 1,
+    omit_term_freq_and_positions => 1
     };
 
 #===================================
@@ -124,46 +130,36 @@ has_type 'Moose::Meta::TypeConstraint::Parameterized',
     inflate_via { _parameterized( 'inflator', @_ ) },
     map_via { _parameterized( 'mapper', @_ ) };
 
+#===================================
+sub _pass_through { $_[0] }
+#===================================
+
 #===================================
 sub _flate_array {
 #===================================
     my $content = _content_handler(@_) or return;
-    return sub {
+    sub {
         [ map { $content->($_) } @{ shift() } ];
-        }
-        if ref $content;
-
-    'do { [map { my $val = $_; ' . $content . '} @$val]}';
+    };
 }
 
 #===================================
 sub _flate_hash {
 #===================================
     my $content = _content_handler(@_) or return;
-    return sub {
+    sub {
         my $hash = shift;
         +{ map { $_ => $content->( $hash->{$_} ) } keys %$hash };
-        }
-        if ref $content;
-
-    'do { '
-        . 'my $hash = $val; '
-        . '+{map { '
-        . 'my $key = $_; my $val = $hash->{$_}; '
-        . '$key => '
-        . $content
-        . '} keys %$hash}}';
+    };
 }
 
 #===================================
 sub _flate_maybe {
 #===================================
     my $content = _content_handler(@_) or return;
-    return sub {
+    sub {
         return defined $_[0] ? $content->( $_[0] ) : undef;
-        }
-        if ref $content;
-    'defined $val ? ' . $content . ' : undef';
+    };
 }
 
 #===================================
@@ -192,14 +188,14 @@ sub _content_handler {
     return $tc->can('type_parameter')
         ? $map->find( $type, $tc->type_parameter, $attr )
         : $type eq 'mapper' ? ( type => 'object', enabled => 0 )
-        :                     '$val';
+        :                     \&_pass_through;
 }
 
 1;
 
-=pod
 
-=encoding UTF-8
+
+=pod
 
 =head1 NAME
 
@@ -207,7 +203,7 @@ Elastic::Model::TypeMap::Moose - Type maps for core Moose types
 
 =head1 VERSION
 
-version 0.29_2
+version 0.01
 
 =head1 DESCRIPTION
 
@@ -246,12 +242,7 @@ In/deflation via L</Any>. It is mapped as:
 
 An undef value is stored as a JSON C<null>. The mapping and in/deflation depend
 on the content type, eg C<Maybe[Int]>.  A C<Maybe> without a content
-type is mapped and in/deflated via L</Any>.  C<Maybe[Bool]> is special cased
-to be mapped as:
-
-    { type => 'boolean' }
-
-See L<Elastic::Manual::Attributes/BOOLEAN FIELDS> for an explanation.
+type is mapped and in/deflated via L</Any>
 
 =head2 Undef
 
@@ -276,7 +267,9 @@ Values are passed through without inflation/deflation. Mapped as:
 
     {
         type                         => 'string',
-        index                        => 'not_analyzed'
+        index                        => 'not_analyzed',
+        omit_norms                   => 1,
+        omit_term_freq_and_positions => 1
     }
 
 =head2 Num
@@ -340,13 +333,14 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Clinton Gormley.
+This software is copyright (c) 2012 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
 __END__
 
 # ABSTRACT: Type maps for core Moose types
