@@ -1,5 +1,8 @@
 package Elastic::Model::TypeMap::Objects;
-$Elastic::Model::TypeMap::Objects::VERSION = '0.29_2'; # TRIAL
+{
+  $Elastic::Model::TypeMap::Objects::VERSION = '0.01'; # TRIAL
+}
+
 use strict;
 use warnings;
 use Elastic::Model::TypeMap::Base qw(:all);
@@ -95,8 +98,8 @@ sub _map_class {
 
     return ( type => 'object', enabled => 0 )
         if $attr->can('has_enabled')
-        && $attr->has_enabled
-        && !$attr->enabled;
+            && $attr->has_enabled
+            && !$attr->enabled;
 
     my $class = $tc->name;
     my $attrs = _class_attrs( $map, $class, $attr )
@@ -144,19 +147,17 @@ sub _class_attrs {
 
 # ABSTRACT: Type maps for objects and Moose classes
 
+
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Elastic::Model::TypeMap::Objects - Type maps for objects and Moose classes
 
 =head1 VERSION
 
-version 0.29_2
+version 0.01
 
 =head1 DESCRIPTION
 
@@ -205,7 +206,8 @@ the L<Elastic::Model::Trait::Field> trait:
     has 'foo' => (
         is              => 'rw,
         isa             => 'Str',
-        trait           => ['Elastic::Model::Trait::Field']
+        trait           => ['Elastic::Model::Trait::Field'],
+        omit_norms      => 1
     );
 
 =head2 Elastic::Doc classes
@@ -252,9 +254,10 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Clinton Gormley.
+This software is copyright (c) 2012 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
