@@ -1,5 +1,8 @@
 package Elastic::Model::TypeMap::Structured;
-$Elastic::Model::TypeMap::Structured::VERSION = '0.29_2'; # TRIAL
+{
+  $Elastic::Model::TypeMap::Structured::VERSION = '0.01'; # TRIAL
+}
+
 use strict;
 use warnings;
 
@@ -53,9 +56,8 @@ has_type 'MooseX::Types::Structured::Map',
 sub _deflate_tuple {
 #===================================
     my $dict = _tuple_to_dict(shift);
-    return '$val' unless %$dict;
-
-    my $deflator = _flate_dict( 'deflator', $dict, @_ );
+    return \&_pass_through unless %$dict;
+    my $deflator = _flate_dict( 'deflator', $dict, @_, );
 
     return sub {
         my $array = shift;
@@ -69,7 +71,7 @@ sub _deflate_tuple {
 sub _inflate_tuple {
 #===================================
     my $dict = _tuple_to_dict(shift);
-    return '$val' unless %$dict;
+    return \&_pass_through unless %$dict;
     my $inflator = _flate_dict( 'inflator', $dict, @_ );
     sub {
         my $hash = $inflator->(@_);
@@ -89,19 +91,13 @@ sub _flate_dict {
 #===================================
     my ( $type, $dict, $attr, $map ) = @_;
 
-    return '$val' unless %$dict;
+    return \&_pass_through unless %$dict;
 
     my %flators;
 
     for my $key ( keys %$dict ) {
-        my $flator = $map->find( $type, $dict->{$key}, $attr )
+        $flators{$key} = $map->find( $type, $dict->{$key}, $attr )
             || die "No $type found for key ($key)";
-
-        $flators{$key}
-            = ref $flator
-            ? $flator
-            : Eval::Closure::eval_closure(
-            source => [ 'sub { my $val = $_[0];', $flator, '}' ] );
     }
 
     sub {
@@ -145,20 +141,10 @@ sub _flate_map {
 
     my $content = $map->find( $type, $content_tc, $attr ) or return;
 
-    return sub {
+    sub {
         my $hash = shift;
         +{ map { $_ => $content->( $hash->{$_} ) } keys %$hash };
-        }
-        if ref $content;
-
-    'do { '
-        . 'my $hash = $val; '
-        . '+{map { '
-        . 'my $key = $_; my $val = $hash->{$_}; '
-        . '$key => '
-        . $content
-        . '} keys %$hash}}';
-
+    };
 }
 
 #===================================
@@ -180,7 +166,7 @@ sub _content_handler {
     return $tc->can('type_parameter')
         ? $map->find( $type, $tc->type_parameter, $attr )
         : $type eq 'mapper' ? ( type => 'object', enabled => 0 )
-        :                     '$val';
+        :                     \&_pass_through;
 }
 
 #===================================
@@ -189,9 +175,9 @@ sub _pass_through { $_[0] }
 
 1;
 
-=pod
 
-=encoding UTF-8
+
+=pod
 
 =head1 NAME
 
@@ -199,7 +185,7 @@ Elastic::Model::TypeMap::Structured - Type maps for MooseX::Types::Structured
 
 =head1 VERSION
 
-version 0.29_2
+version 0.01
 
 =head1 DESCRIPTION
 
@@ -218,7 +204,7 @@ and the value would be passed through unaltered when deflating/inflating.
 
 =head2 Tuple
 
-Because array refs are interpreted by Elasticsearch as multiple values
+Because array refs are interpreted by ElasticSearch as multiple values
 of the same type, tuples are converted to hash refs whose keys are
 the index number.  For instance, a field C<foo> with C<Tuple[Int,Str]>
 and value C<[5,'foo']> will be deflated to C<< { 0 => 5, 1 => 'foo' } >>.
@@ -263,13 +249,14 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Clinton Gormley.
+This software is copyright (c) 2012 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
 __END__
 
 # ABSTRACT: Type maps for MooseX::Types::Structured
