@@ -1,10 +1,13 @@
 package Elastic::Model::Types;
-$Elastic::Model::Types::VERSION = '0.29_2'; # TRIAL
+{
+  $Elastic::Model::Types::VERSION = '0.01'; # TRIAL
+}
+
 use strict;
 use warnings;
-use Search::Elasticsearch();
+use ElasticSearch();
 
-use MooseX::Types::Moose qw(HashRef ArrayRef Str Bool Num Int Defined Any);
+use MooseX::Types::Moose qw(:all);
 use MooseX::Types::Structured qw (Dict Optional Map);
 use namespace::autoclean;
 
@@ -15,14 +18,11 @@ use MooseX::Types -declare => [ qw(
         CoreFieldType
         DynamicMapping
         ES
-        ES_1x
-        ES_90
         FieldType
         GeoPoint
         HighlightArgs
         IndexMapping
         IndexNames
-        Keyword
         Latitude
         Longitude
         MultiField
@@ -76,21 +76,18 @@ while ( my $type = shift @enums ) {
     );
 }
 
-class_type ES_1x, { class => 'Search::Elasticsearch::Client::Direct' };
-class_type ES_90, { class => 'Search::Elasticsearch::Client::0_90::Direct' };
-
 #===================================
-subtype ES(), as ES_1x | ES_90;
+class_type ES, { class => 'ElasticSearch' };
 #===================================
-coerce ES, from HashRef, via { Search::Elasticsearch->new($_) };
+coerce ES, from HashRef, via { ElasticSearch->new($_) };
 coerce ES, from Str, via {
     s/^:/127.0.0.1:/;
-    Search::Elasticsearch->new( nodes => $_ );
+    ElasticSearch->new( servers => $_ );
 };
 coerce ES, from ArrayRef, via {
-    my @nodes = @$_;
-    s/^:/127.0.0.1:/ for @nodes;
-    Search::Elasticsearch->new( servers => \@nodes );
+    my @servers = @$_;
+    s/^:/127.0.0.1:/ for @servers;
+    ElasticSearch->new( servers => \@servers );
 };
 
 #===================================
@@ -101,21 +98,23 @@ coerce StoreMapping, from Any, via { $_ ? 'yes' : 'no' };
 #===================================
 subtype MultiField, as Dict [
 #===================================
-    type                  => Optional [CoreFieldType],
-    index                 => Optional [IndexMapping],
-    index_name            => Optional [Str],
-    boost                 => Optional [Num],
-    null_value            => Optional [Str],
-    analyzer              => Optional [Str],
-    index_analyzer        => Optional [Str],
-    search_analyzer       => Optional [Str],
-    search_quote_analyzer => Optional [Str],
-    term_vector           => Optional [TermVectorMapping],
-    geohash               => Optional [Bool],
-    lat_lon               => Optional [Bool],
-    geohash_precision     => Optional [Int],
-    precision_step        => Optional [Int],
-    format                => Optional [Str],
+    type                         => Optional [CoreFieldType],
+    index                        => Optional [IndexMapping],
+    index_name                   => Optional [Str],
+    boost                        => Optional [Num],
+    null_value                   => Optional [Str],
+    analyzer                     => Optional [Str],
+    index_analyzer               => Optional [Str],
+    search_analyzer              => Optional [Str],
+    search_quote_analyzer        => Optional [Str],
+    omit_norms                   => Optional [Bool],
+    omit_term_freq_and_positions => Optional [Bool],
+    term_vector                  => Optional [TermVectorMapping],
+    geohash                      => Optional [Bool],
+    lat_lon                      => Optional [Bool],
+    geohash_precision            => Optional [Int],
+    precision_step               => Optional [Int],
+    format                       => Optional [Str],
 
 ];
 
@@ -186,10 +185,6 @@ coerce ArrayRefOfStr, from Str, via { [$_] };
 subtype Timestamp, as Num;
 #===================================
 
-#===================================
-subtype Keyword, as Str;
-#===================================
-
 #===================================
 class_type UID, { class => 'Elastic::Model::UID' };
 #===================================
@@ -198,9 +193,9 @@ coerce UID, from HashRef, via { Elastic::Model::UID->new($_) };
 
 1;
 
-=pod
 
-=encoding UTF-8
+
+=pod
 
 =head1 NAME
 
@@ -208,7 +203,7 @@ Elastic::Model::Types - MooseX::Types for general and internal use
 
 =head1 VERSION
 
-version 0.29_2
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -227,19 +222,6 @@ use and some which will be useful generally.
 
 =head1 PUBLIC TYPES
 
-=head2 Keyword
-
-    use Elastic::Model::Types qw(Keyword);
-
-    has 'status' => (
-        is  => 'ro',
-        isa => Keyword
-    );
-
-C<Keyword> is a sub-type of C<Str>.  It is provided to make it easy to map
-string values which should not be analyzed (eg a C<status> field rather than
-a C<comment_body> field). See L<Elastic::Model::TypeMap::ES/Keyword>.
-
 =head2 Binary
 
     use Elastic::Model::Types qw(Binary);
@@ -287,8 +269,9 @@ C<Str> with C<"$lat,$lon">.
         isa => Timestamp
     );
 
-A C<Timestamp> is a C<Num> which holds floating point epoch seconds, with milliseconds resolution.
-It is automatically mapped as a C<date> field in Elasticsearch.
+A C<Timestamp> is a C<Num> which holds floating epoch seconds, with milliseconds
+as decimal places. It is automatically mapped as a C<date> field in
+ElasticSearch.
 
 =head1 AUTHOR
 
@@ -296,13 +279,14 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Clinton Gormley.
+This software is copyright (c) 2012 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
 __END__
 
 # ABSTRACT: MooseX::Types for general and internal use
