@@ -1,7 +1,10 @@
 package Elastic::Model::UID;
-$Elastic::Model::UID::VERSION = '0.29_2'; # TRIAL
+{
+  $Elastic::Model::UID::VERSION = '0.01'; # TRIAL
+}
+
 use Moose;
-use MooseX::Types::Moose qw(Str Int Maybe Bool);
+use MooseX::Types::Moose qw(:all);
 use namespace::autoclean;
 
 #===================================
@@ -53,13 +56,6 @@ has from_store => (
     writer => '_from_store'
 );
 
-#===================================
-has 'is_partial' => (
-#===================================
-    is  => 'ro',
-    isa => Bool,
-);
-
 #===================================
 has cache_key => (
 #===================================
@@ -79,20 +75,7 @@ sub new_from_store {
     my %params = %{ shift() };
     $class->new(
         from_store => 1,
-        routing    => $params{fields}{_routing},
-        map { $_ => $params{"_$_"} } qw(index type id version)
-    );
-}
-
-#===================================
-sub new_partial {
-#===================================
-    my $class  = shift;
-    my %params = %{ shift() };
-    $class->new(
-        from_store => 1,
-        is_partial => 1,
-        routing    => $params{fields}{_routing},
+        routing    => $params{fields}{routing},
         map { $_ => $params{"_$_"} } qw(index type id version)
     );
 }
@@ -152,21 +135,19 @@ sub _build_cache_key {
     return join ";", map { s/;/;;/g; $_ } map { $self->$_ } qw(type id);
 }
 
-__PACKAGE__->meta->make_immutable;
-
 1;
 
+
+
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
-Elastic::Model::UID - The Unique ID of a document in an Elasticsearch cluster
+Elastic::Model::UID - The Unique ID of a document in an ElasticSearch cluster
 
 =head1 VERSION
 
-version 0.29_2
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -191,7 +172,7 @@ version 0.29_2
 
 =head1 DESCRIPTION
 
-To truly identify a document as unique in Elasticsearch, you need to know
+To truly identify a document as unique in ElasticSearch, you need to know
 the L<index|Elastic::Model::Terminology/Index> where it is stored, the
 L<type|Elastic::Model::Terminology/Type> of the document, its
 L<id|Elastic::Model::Terminology/ID>, and
@@ -224,7 +205,7 @@ document is saved.
 =head2 routing
 
 The L<routing|Elastic::Model::Terminology/Routing> string is used to determine
-in which shard the document lives. If not specified, then Elasticsearch
+in which shard the document lives. If not specified, then ElasticSearch
 generates a routing value using a hash of the ID.  If you use a custom
 routing value, then you can't change that value as the new routing B<may>
 point to a new shard.  Instead, you should delete the old doc, and create a
@@ -238,14 +219,9 @@ an older version of the document will throw an exception.
 
 =head2 from_store
 
-A boolean value indicating whether the C<UID> was loaded from Elasticsearch
+A boolean value indicating whether the C<UID> was loaded from ElasticSearch
 (C<true>) or created via L</"new()">.
 
-=head2 is_partial
-
-A boolean value indicating whether the C<UID> represents a partial or full
-object. Partial objects cannot be saved.
-
 =head2 cache_key
 
 A generated string combining the L</"type"> and the L</"id">
@@ -274,20 +250,7 @@ Creates a new UID with L</"from_store"> set to false.
     );
 
 This is called when creating a new UID for a doc that has been loaded
-from Elasticsearch. You shouldn't need to use this method directly.
-
-=head2 new_partial()
-
-    $uid = Elastic::Model::UID->new_partial(
-        _index   => $index,
-        _type    => $type,
-        _id      => $id,
-        _version => $version,
-        fields   => { routing => $routing }
-    );
-
-This is called when creating a new UID for a partial doc that has been loaded
-from Elasticsearch. You shouldn't need to use this method directly.
+from ElasticSearch. You shouldn't need to use this method directly.
 
 =head2 clone()
 
@@ -335,14 +298,15 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Clinton Gormley.
+This software is copyright (c) 2012 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
 __END__
 
-# ABSTRACT: The Unique ID of a document in an Elasticsearch cluster
+# ABSTRACT: The Unique ID of a document in an ElasticSearch cluster
 
