@@ -1,5 +1,8 @@
 package Elastic::Model::View;
-$Elastic::Model::View::VERSION = '0.29_2'; # TRIAL
+{
+  $Elastic::Model::View::VERSION = '0.01'; # TRIAL
+}
+
 use Moose;
 
 use Carp;
@@ -7,7 +10,7 @@ use Elastic::Model::Types qw(
     IndexNames ArrayRefOfStr SortArgs
     HighlightArgs Consistency Replication);
 use MooseX::Types::Moose qw(Str Int HashRef ArrayRef Bool Num Object);
-use Elastic::Model::SearchBuilder();
+
 use namespace::autoclean;
 
 #===================================
@@ -69,7 +72,7 @@ has 'fields' => (
     isa     => ArrayRefOfStr,
     coerce  => 1,
     is      => 'rw',
-    default => sub { [] },
+    default => sub { ['_source'] },
 );
 
 #===================================
@@ -149,22 +152,6 @@ has 'routing' => (
     is     => 'rw',
 );
 
-#===================================
-has 'include_paths' => (
-#===================================
-    is        => 'rw',
-    isa       => ArrayRef [Str],
-    predicate => '_has_include_paths'
-);
-
-#===================================
-has 'exclude_paths' => (
-#===================================
-    is        => 'rw',
-    isa       => ArrayRef [Str],
-    predicate => '_has_exclude_paths'
-);
-
 #===================================
 has 'script_fields' => (
 #===================================
@@ -231,51 +218,31 @@ has 'search_builder' => (
 );
 
 #===================================
-has 'cache' => (
-#===================================
-    is  => 'rw',
-    isa => Object,
-);
-
-#===================================
-has 'cache_opts' => (
-#===================================
-    is  => 'rw',
-    isa => HashRef,
-);
-
-#===================================
-sub _build_search_builder { Elastic::Model::SearchBuilder->new }
+sub _build_search_builder { shift->model->es->builder }
 #===================================
 
 #===================================
 sub queryb {
 #===================================
-    my $self  = shift;
-    my @args  = @_ > 1 ? {@_} : shift();
-    my $query = $self->search_builder->query(@args)
-        or return $self->_clone_self;
-    $self->query( $query->{query} );
+    my $self = shift;
+    my @args = @_ > 1 ? {@_} : shift();
+    $self->query( $self->search_builder->query(@args)->{query} );
 }
 
 #===================================
 sub filterb {
 #===================================
-    my $self   = shift;
-    my @args   = @_ > 1 ? {@_} : shift();
-    my $filter = $self->search_builder->filter(@args)
-        or return $self->_clone_self;
-    $self->filter( $filter->{filter} );
+    my $self = shift;
+    my @args = @_ > 1 ? {@_} : shift();
+    $self->filter( $self->search_builder->filter(@args)->{filter} );
 }
 
 #===================================
 sub post_filterb {
 #===================================
-    my $self   = shift;
-    my @args   = @_ > 1 ? {@_} : shift();
-    my $filter = $self->search_builder->filter(@args)
-        or return $self->_clone_self;
-    $self->post_filter( $filter->{filter} );
+    my $self = shift;
+    my @args = @_ > 1 ? {@_} : shift();
+    $self->post_filter( $self->search_builder->filter(@args)->{filter} );
 }
 
 #===================================
@@ -284,23 +251,22 @@ sub post_filterb {
 
 around [
 #===================================
-    'from',           'size',        'timeout',   'track_scores',
-    'search_builder', 'preference',  'min_score', 'explain',
-    'consistency',    'replication', 'cache'
+    'from',           'size',       'timeout',   'track_scores',
+    'search_builder', 'preference', 'min_score', 'explain',
+    'consistency',    'replication'
 #===================================
 ] => sub { _clone_args( \&_scalar_args, @_ ) };
 
 around [
 #===================================
-    'domain',        'type', 'fields', 'sort', 'routing', 'stats',
-    'include_paths', 'exclude_paths'
+    'domain', 'type', 'fields', 'sort', 'routing', 'stats'
 #===================================
 ] => sub { _clone_args( \&_array_args, @_ ) };
 
 around [
 #===================================
     'facets', 'index_boosts', 'script_fields', 'highlighting',
-    'query',  'filter',       'post_filter',   'cache_opts'
+    'query',  'filter',       'post_filter'
 #===================================
 ] => sub { _clone_args( \&_hash_args, @_ ) };
 
@@ -344,13 +310,6 @@ sub _clone_args {
     $self->$orig();
 }
 
-#===================================
-sub _clone_self {
-#===================================
-    my $self = shift;
-    return bless {%$self}, ref $self;
-}
-
 #===================================
 sub _check_no_fields {
 #===================================
@@ -392,23 +351,6 @@ sub search {
         ->as_results;
 }
 
-#===================================
-sub cached_search {
-#===================================
-    my $self  = shift;
-    my $cache = $self->cache
-        or return $self->search;
-
-    my %cache_opts
-        = ( %{ $self->cache_opts || {} }, @_ == 1 ? %{ $_[0] } : @_ );
-
-    $self->model->cached_results_class->new(
-        search     => $self->_build_search,
-        cache      => $cache,
-        cache_opts => \%cache_opts
-    )->as_results;
-}
-
 #===================================
 sub scroll { shift->_scroll(@_)->as_results }
 #===================================
@@ -447,38 +389,31 @@ sub _build_search {
 #===================================
     my $self = shift;
 
-    my ( $highlight, $hfields );
-    if ( $hfields = $self->highlight and keys %$hfields ) {
-        $highlight = { %{ $self->highlighting || {} }, fields => $hfields };
+    my ( $highlight, $fields );
+    if ( $fields = $self->highlight and keys %$fields ) {
+        $highlight = { %{ $self->highlighting || {} }, fields => $fields };
     }
 
-    my $fields = $self->fields;
-
-    my $source;
-    $source->{include} = $self->include_paths
-        if $self->_has_include_paths;
-    $source->{exclude} = $self->exclude_paths
-        if $self->_has_exclude_paths;
-    $source ||= @$fields ? 0 : 1;
-
-    my %args = _strip_undef(
-        (   map { $_ => $self->$_ }
+    my %args = ( (
+            map { $_ => $self->$_ }
                 qw(
                 type sort from size facets
-                min_score post_filter preference routing stats
+                min_score preference routing stats
                 script_fields timeout track_scores explain
                 )
         ),
         index         => $self->domain,
+        filter        => $self->post_filter,
         query         => $self->_build_query,
         highlight     => $highlight,
         indices_boost => $self->index_boosts,
         @_,
         version => 1,
-        fields  => [ '_parent', '_routing', @$fields ],
-        _source => $source,
+        fields  => [ '_parent', '_routing', @{ $self->fields } ],
+
     );
-    return \%args;
+
+    return { map { $_ => $args{$_} } grep { defined $args{$_} } keys %args };
 }
 
 #===================================
@@ -487,7 +422,7 @@ sub _build_query {
     my $self = shift;
     my $q    = $self->query;
     my $f    = $self->filter;
-    return { match_all => {} } unless $q || $f;
+    return { match_all => {} } unless $q or $f;
 
     return
          !$q ? { constant_score => { filter => $f } }
@@ -499,34 +434,28 @@ sub _build_query {
 sub _build_delete {
 #===================================
     my $self = shift;
-    my %args = _strip_undef(
+    my %args = (
         index => $self->domain,
         ( map { $_ => $self->$_ } qw(type routing consistency replication) ),
-        @_,
         query => $self->_build_query,
+        @_
     );
-    return \%args;
+    return { map { $_ => $args{$_} } grep { defined $args{$_} } keys %args };
 }
 
-#===================================
-sub _strip_undef {
-#===================================
-    my %args = @_;
-    return map { $_ => $args{$_} } grep { defined $args{$_} } keys %args;
-}
 1;
 
+
+
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
-Elastic::Model::View - Views to query your docs in Elasticsearch
+Elastic::Model::View - Views to query your docs in ElasticSearch
 
 =head1 VERSION
 
-version 0.29_2
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -563,21 +492,13 @@ Efficiently retrieve all posts, unsorted:
 
     $results = $posts->size(100)->scan;
 
-    while (my $result = $results->shift_result) {
+    while (my $result = $results->shift_result)) {
         do_something_with($result);
     );
 
-Cached results:
-
-    $cache   = CHI->new(....);
-    $view    = $view->cache( $cache )->cache_opts( expires_in => '2 min');
-
-    $results = $view->queryb( 'perl' )->cached_search();
-    $results = $view->queryb( 'perl' )->cached_search( expires => '30 sec');
-
 =head1 DESCRIPTION
 
-L<Elastic::Model::View> is used to query your docs in Elasticsearch.
+L<Elastic::Model::View> is used to query your docs in ElasticSearch.
 
 Views are "chainable". In other words, you get a clone of the
 current view every time you set an attribute. For instance, you could do:
@@ -619,50 +540,15 @@ with at most L</size> results.
 This is useful for returning finite results, ie where you know how many
 results you want.  For instance: I<"give me the 10 best results">.
 
-=head2 cached_search()
-
-B<NOTE: Think carefully before you cache data outside of Elasticsearch.
-Elasticsearch already has smart filter caches, which are updated as your data
-changes. Most of the time, you will be better off using those directly,
-instead of an external cache.>
-
-    $results = $view->cache( $cache )->cached_search( %opts );
-
-If a L</cache> attribute has been specified for the current view, then
-L</cached_search()> tries to retrieve the search results from the L</cache>.
-If it fails, then a L</search()> is executed, and the results are stored in
-the L</cache>. An L<Elastic::Model::Results::Cached> object is returned.
-
-Any C<%opts> that are passed in override any default L</cache_opts>, and are
-passed to L<CHI's get() or set()|'https://metacpan.org/module/CHI#Getting-and-setting>
-methods.
-
-    $view    = $view->cache_opts( expires_in => '30 sec' );
-
-    $results = $view->cached_search;                            # 30 seconds
-    $results = $view->cached_search( expires_in => '2 min' );   #  2 minutes
-
-Given the near-real-time nature of Elasticsearch, you sometimes want to
-invalidate a cached result in the near future.  For instance, if you have
-cached a list of comments on a blog post, but then you add a new comment,
-you want to invalidate the cached comments list.  However, the new
-comment will only become visible to search sometime within the next second, so
-invalidating the cache immediately may or may not be useful.
-
-Use the special argument C<force_set> to bypass the cache C<get()> and to force
-the cached version to be updated, along with a new expiry time:
-
-    $results = $view->cached_search( force_set => 1, expires_in => '2 sec');
-
 =head2 scroll()
 
     $scroll_timeout = '1m';
     $scrolled_results = $view->scroll( $scroll_timeout );
 
 Executes a search and returns an L<Elastic::Model::Results::Scrolled>
-object which will pull L</size> results from Elasticsearch as required until
+object which will pull L</size> results from ElasticSearch as required until
 either (1) no more results are available or (2) more than C<$scroll_timeout>
-(default 1 minute) elapses between requests to Elasticsearch.
+(default 1 minute) elapses between requests to ElasticSearch.
 
 Scrolling allows you to return an unbound result set.  Useful if you're not
 sure whether to expect 2 results or 2000.
@@ -697,8 +583,7 @@ All other metadta is thrown away.
 
 Deletes all docs matching the query and returns a hashref indicating
 success. Any docs that are stored in a live L<scope|Elastic::Model::Scope>
-or are cached somewhere are not removed. Any
-L<unique keys|Elastic::Manual::Attributes::Unique> are not removed.
+or are cached somewhere are not removed.
 
 This should really only be used once you are sure that the matching docs
 are out of circulation.  Also, it is more efficient to just delete a whole index
@@ -747,12 +632,12 @@ one or more types.
     \%query   = $view->query
 
 Specify the query to run in the native
-L<Elasticsearch query DSL|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/query-dsl.html>
+L<ElasticSearch query DSL|http://www.elasticsearch.org/guide/reference/query-dsl/>
 or use C<queryb()> to specify your query  with the more Perlish
-L<Elastic::Model::SearchBuilder> query syntax.
+L<ElasticSearch::SearchBuilder> query syntax.
 
 By default, the query will
-L<match all docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/query-dsl-match-all-query.html>.
+L<match all docs|http://www.elasticsearch.org/guide/reference/query-dsl/match-all-query.html>.
 
 =head2 filter
 
@@ -767,12 +652,12 @@ L<match all docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/c
     \%filter  = $view->filter;
 
 You can specify a filter to apply to the query results using either
-the native Elasticsearch query DSL or, use C<filterb()> to specify your
-filter with the more Perlish L<Elastic::Model::SearchBuilder> DSL.
+the native ElasticSearch query DSL or, use C<filterb()> to specify your
+filter with the more Perlish L<ElasticSearch::SearchBuilder> DSL.
 If a filter is specified, it will be combined with the L</query>
-as a L<filtered query|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/query-dsl-filtered-query.html>,
+as a L<filtered query|http://www.elasticsearch.org/guide/reference/query-dsl/filtered-query.html>,
 or (if no query is specified) as a
-L<constant score|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/query-dsl-constant-score-query.html>
+L<constant score|http://www.elasticsearch.org/guide/reference/query-dsl/constant-score-query.html>
 query.
 
 =head2 post_filter
@@ -787,14 +672,14 @@ query.
 
     \%filter  = $view->post_filter;
 
-L<Post-filters|http://www.elasticsearch.org/guide/en/elasticsearch/reference/0.90/search-request-post-filter.html>
+L<Post-filters|http://www.elasticsearch.org/guide/reference/api/search/filter.html>
 filter the results AFTER any L</facets> have been calculated.  In the above
 example, the facets would be calculated on all values of C<tag>, but the
 results would then be limited to just those docs where C<tag == perl>.
 
-You can specify a post_filter using either the native Elasticsearch query DSL or,
+You can specify a post_filter using either the native ElasticSearch query DSL or,
 use C<post_filterb()> to specify it with the more Perlish
-L<Elastic::Model::SearchBuilder> DSL.
+L<ElasticSearch::SearchBuilder> DSL.
 
 =head2 sort
 
@@ -813,7 +698,7 @@ L<Elastic::Model::SearchBuilder> DSL.
 By default, results are sorted by "relevance" (C<< _score => 'desc' >>).
 You can specify multiple sort arguments, which are applied in order, and
 can include scripts or geo-distance.
-See L<http://www.elasticsearch.org/guide/en/elasticsearch/reference/0.90/search-request-sort.html> for
+See L<http://www.elasticsearch.org/guide/reference/api/search/sort.html> for
 more information.
 
 B<Note:> Sorting cannot be combined with L</scan()>.
@@ -824,10 +709,8 @@ B<Note:> Sorting cannot be combined with L</scan()>.
 
     $from     = $view->from;
 
-By default, results are returned from the first result. Think of it as
-I<"the number of docs to skip">, so setting C<from> to C<0> would start from
-the first result. Setting C<from> to C<10> would skip the first 10 results
-and return docs from result number 11 onwards.
+By default, results are returned from the first result. If you would like to
+start at a later result (eg for paging), you can set L</from>.
 
 =head2 size
 
@@ -865,7 +748,7 @@ from the query generated from L</query> and L</filter>.  If you want to filter
 your query results down further after calculating your facets, you can
 use L</post_filter>.
 
-See L<http://www.elasticsearch.org/guide/en/elasticsearch/reference/0.90/search-facets.html> for
+See L<http://www.elasticsearch.org/guide/reference/api/search/facets/> for
 an explanation of what facets are available.
 
 =head2 highlight
@@ -877,7 +760,7 @@ an explanation of what facets are available.
     );
 
 Specify which fields should be used for
-L<highlighted snippets|http://www.elasticsearch.org/guide/en/elasticsearch/reference/0.90/search-request-highlighting.html>.
+L<highlighted snippets|http://www.elasticsearch.org/guide/reference/api/search/highlighting.html>.
 to your search results. You can pass just a list of fields, or fields with
 their field-specific settings. These values are used to set the C<fields>
 parameter in L</highlighting>.
@@ -896,7 +779,7 @@ which should be applied to all of the fields set in L</highlight> (although
 you can override these settings for individual fields by passing field settings
 to L</highlight>).
 
-See L<http://www.elasticsearch.org/guide/en/elasticsearch/reference/0.90/search-request-highlighting.html>.
+See L<http://www.elasticsearch.org/guide/reference/api/search/highlighting.html>.
 for more about how highlighting works, and L<Elastic::Model::Result/highlight>
 for how to retrieve the highlighted snippets.
 
@@ -906,15 +789,15 @@ for how to retrieve the highlighted snippets.
 
     $new_view = $view->fields('title','content');
 
-By default, searches will return the L<_source|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/mapping-source-field.html>
+By default, searches will return the L<_source|http://www.elasticsearch.org/guide/reference/mapping/source-field.html>
 field which contains the whole document, allowing Elastic::Model to inflate
 the original object without having to retrieve the document separately. If you
 would like to just retrieve a subset of fields, you can specify them in
-L</fields>. See L<http://www.elasticsearch.org/guide/en/elasticsearch/reference/0.90/search-request-fields.html>.
+L</fields>. See L<http://www.elasticsearch.org/guide/reference/api/search/fields.html>.
 
 B<Note:> If you do specify any fields, and you DON'T include C<'_source'> then the
 C<_source> field won't be returned, and you won't be able to retrieve the original
-object without requesting it from Elasticsearch in a separate (but automatic) step.
+object without requesting it from ElasticSearch in a separate (but automatic) step.
 
 =head2 script_fields
 
@@ -933,30 +816,9 @@ object without requesting it from Elasticsearch in a separate (but automatic) st
     \%fields  = $view->script_fields;
     \%defn    = $view->get_script_field($name);
 
-L<Script fields|http://www.elasticsearch.org/guide/en/elasticsearch/reference/0.90/search-request-script-fields.html>
+L<Script fields|http://www.elasticsearch.org/guide/reference/api/search/script-fields.html>
 can be generated using the L<mvel|http://mvel.codehaus.org/Language+Guide+for+2.0>
-scripting language. (You can also use L<Javascript, Python and Java|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/modules-scripting.html>.)
-
-=head2 include_paths / exclude_paths
-
-    $new_view    = $view->include_paths('foo.*')
-                        ->exclude_paths('foo.bar.*','baz.*');
-
-    $results     = $new_view->search->as_partials;
-    $partial_obj = $results->next;
-
-If your objects are large, but you only need access to a few attributes to
-eg display search results, you may want to retrieve only the relevant parts of
-each object.  You can specify which parts of the object to include or exclude
-using C<include_paths> and C<exclude_paths>. If either of these is set
-then the full C<_source> field will not be loaded (unless you specify it
-explicitly using L</fields>).
-
-The partial objects returned when L<Elastic::Model::Results/as_partials()>
-is in effect function exactly as real objects, except that they cannot
-be saved.
-
-See C<Partial fields> on L<http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/search-request-fields.html#partial>.
+scripting language. (You can also use L<Javascript, Python and Java|http://www.elasticsearch.org/guide/reference/modules/scripting>.)
 
 =head2 routing
 
@@ -998,7 +860,7 @@ Exclude results whose score (relevance) is less than the specified number.
     $new_view = $view->preference( '_local' );
 
 Control which node should return search results. See
-L<http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/search-request-preference.html> for more.
+L<http://www.elasticsearch.org/guide/reference/api/search/preference.html> for more.
 
 =head2 timeout
 
@@ -1015,31 +877,10 @@ with whatever results it has managed to receive up until that point.
     $new_view = $view->track_scores( 1 );
     $track    = $view->track_scores;
 
-By default, If you sort on a field other than C<_score>, Elasticsearch
+By default, If you sort on a field other than C<_score>, ElasticSearch
 does not return the calculated relevance score for each doc.  If
 L</track_scores> is true, these scores will be returned regardless.
 
-=head1 CACHING ATTRIBUTES
-
-Bounded searches (those returned by calling L</search()>) can be stored
-in a L<CHI>-compatible cache.
-
-=head2 cache
-
-    $cache    = CHI->new(...);
-    $new_view = $view->cache( $cache );
-
-Stores an instance of a L<CHI>-compatible cache, to be used with
-L</cached_search()>.
-
-=head2 cache_opts
-
-    $new_view = $view->cache_opts( expires_in => '20 sec', ...);
-
-Stores the default options that should be passed to
-L<CHI's get() or set()|'https://metacpan.org/module/CHI#Getting-and-setting>.
-These can be overridden by passing options to L</cached_search()>.
-
 =head1 DEBUGGING ATTRIBUTES
 
 =head2 explain
@@ -1057,7 +898,7 @@ L<Elastic::Model::Result/explain> to view the output.
     \@groups  = $view->stats;
 
 The statistics for each search can be aggregated by C<group>. These stats
-can later be retrieved using L<Search::Elasticsearch::Compat/index_stats()>.
+can later be retrieved using L<ElasticSearch/index_stats()>.
 
 =head2 search_builder
 
@@ -1065,7 +906,7 @@ can later be retrieved using L<Search::Elasticsearch::Compat/index_stats()>.
     $builder  = $view->search_builder;
 
 If you would like to use a different search builder than the default
-L<Elastic::Model::SearchBuilder> for L</"queryb">, L</"filterb"> or
+L<ElasticSearch::SearchBuilder> for L</"queryb">, L</"filterb"> or
 L</post_filterb>, then you can set a value for L</search_builder>.
 
 =head1 DELETE ATTRIBUTES
@@ -1089,20 +930,25 @@ Should a delete be done synchronously (ie waits until all nodes within
 the replcation group have run the delete) or asynchronously (returns
 immediately, and performs the delete in the background).
 
+=head1 TODO
+
+Possibly support L<partial fields|https://github.com/elasticsearch/elasticsearch/issues/1570>
+
 =head1 AUTHOR
 
 Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Clinton Gormley.
+This software is copyright (c) 2012 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
 __END__
 
-# ABSTRACT: Views to query your docs in Elasticsearch
+# ABSTRACT: Views to query your docs in ElasticSearch
 
